Method: Curses.init_color

Defined in:
ext/curses/curses.c

.init_color(color, r, g, b) ⇒ Object

Changes the definition of a color. It takes four arguments:

  • the number of the color to be changed, color

  • the amount of red, r

  • the amount of green, g

  • the amount of blue, b

The value of the first argument must be between 0 and COLORS. (See the section Colors for the default color index.) Each of the last three arguments must be a value between 0 and 1000. When Curses.init_color is used, all occurrences of that color on the screen immediately change to the new definition.



1343
1344
1345
1346
1347
1348
1349
1350
# File 'ext/curses/curses.c', line 1343

static VALUE
curses_init_color(VALUE obj, VALUE color, VALUE r, VALUE g, VALUE b)
{
    /* may have to raise exception on ERR */
    curses_stdscr();
    return (init_color(NUM2INT(color),NUM2INT(r),
           NUM2INT(g),NUM2INT(b)) == OK) ? Qtrue : Qfalse;
}