Method: Curses.nl

Defined in:
ext/curses/curses.c

.nlObject

Enable the underlying display device to translate the return key into newline on input, and whether it translates newline into return and line-feed on output (in either case, the call Curses.addch(‘n’) does the equivalent of return and line feed on the virtual screen).

Initially, these translations do occur. If you disable them using Curses.nonl, curses will be able to make better use of the line-feed capability, resulting in faster cursor motion. Also, curses will then be able to detect the return key.



606
607
608
609
610
611
612
# File 'ext/curses/curses.c', line 606

static VALUE
curses_nl(VALUE obj)
{
    curses_stdscr();
    nl();
    return Qnil;
}