Method: Curses.raw

Defined in:
ext/curses/curses.c

.rawObject

Put the terminal into raw mode.

Raw mode is similar to Curses.cbreak mode, in that characters typed are immediately passed through to the user program.

The differences are that in raw mode, the interrupt, quit, suspend, and flow control characters are all passed through uninterpreted, instead of generating a signal. The behavior of the BREAK key depends on other bits in the tty driver that are not set by curses.



524
525
526
527
528
529
530
# File 'ext/curses/curses.c', line 524

static VALUE
curses_raw(VALUE obj)
{
    curses_stdscr();
    raw();
    return Qnil;
}