Method: Curses::Window#timeout=

Defined in:
ext/curses/curses.c

#timeout=(delay) ⇒ Object

Sets block and non-blocking reads for the window.

  • If delay is negative, blocking read is used (i.e., waits indefinitely for input).

  • If delay is zero, then non-blocking read is used (i.e., read returns ERR if no input is waiting).

  • If delay is positive, then read blocks for delay milliseconds, and returns ERR if there is still no input.



3071
3072
3073
3074
3075
3076
3077
3078
3079
# File 'ext/curses/curses.c', line 3071

static VALUE
window_timeout(VALUE obj, VALUE delay)
{
    struct windata *winp;
    GetWINDOW(obj,winp);

    wtimeout(winp->window,NUM2INT(delay));
    return Qnil;
}