Module: Curses
- Defined in:
- ext/curses/curses.c,
ext/curses/curses.c
Overview
Description
An implementation of the CRT screen handling and optimization library.
Structures and such
Classes
-
Curses::Window - class with the means to draw a window or box
-
Curses::MouseEvent - class for collecting mouse events
Modules
- Curses
-
The curses implementation
- Curses::Key
-
Collection of constants for keypress events
Examples
-
hello.rb
:include: sample/hello.rb -
rain.rb
:include: sample/rain.rb
Defined Under Namespace
Modules: Key Classes: Error, Field, Form, Item, Menu, MouseEvent, Pad, Window
Constant Summary collapse
- VERSION =
Identifies curses library version.
-
“ncurses 5.9.20110404”
-
“PDCurses 3.4 - Public Domain 2008”
-
“curses (SVR4)” (System V curses)
-
“curses (unknown)” (The original BSD curses? NetBSD maybe.)
-
version- TYPE_ALPHA =
INT2NUM(TYPE_CODE_ALPHA)
- TYPE_ALNUM =
INT2NUM(TYPE_CODE_ALNUM)
- TYPE_ENUM =
INT2NUM(TYPE_CODE_ENUM)
- TYPE_INTEGER =
INT2NUM(TYPE_CODE_INTEGER)
- TYPE_NUMERIC =
INT2NUM(TYPE_CODE_NUMERIC)
- TYPE_REGEXP =
INT2NUM(TYPE_CODE_REGEXP)
Class Method Summary collapse
-
.addch(ch) ⇒ Object
Add a character
ch, with attributes, then advance the cursor. -
.addstr(str) ⇒ Object
add a string of characters
str, to the window and advance cursor. -
.assume_default_colors(fg, bg) ⇒ Object
tells which colors to paint for color pair 0.
-
.attroff(attrs) ⇒ Object
Turns off the named attributes
attrswithout affecting any others. -
.attron(attrs) ⇒ Object
Turns on the named attributes
attrswithout turning any other attributes on or off. -
.attrset(attrs) ⇒ Object
Sets the current attributes of the given window to
attrs. -
.beep ⇒ Object
Sounds an audible alarm on the terminal, if possible; otherwise it flashes the screen (visual bell).
-
.bkgd(ch) ⇒ Object
Window background manipulation routines.
-
.bkgdset(ch) ⇒ Object
Manipulate the background of the named window with character Integer
ch. -
.can_change_color? ⇒ Boolean
Returns
trueorfalsedepending on whether the terminal can change color attributes. -
.cbreak ⇒ Object
Put the terminal into cbreak mode.
-
.clear ⇒ Object
Clears every position on the screen completely, so that a subsequent call by Curses.refresh for the screen/window will be repainted from scratch.
-
.close_screen ⇒ Object
A program should always call Curses.close_screen before exiting or escaping from curses mode temporarily.
-
.closed? ⇒ Boolean
Returns
trueif the window/screen has been closed, without any subsequent Curses.refresh calls, returnsfalseotherwise. -
.clrtoeol ⇒ Object
Clears to the end of line, that the cursor is currently on.
-
.color_content(color) ⇒ Object
Returns an 3 item Array of the RGB values in
color. -
.color_pair(attrs) ⇒ Object
Sets the color pair attributes to
attrs. -
.color_pairs ⇒ Object
Returns the COLOR_PAIRS available, if the curses library supports it.
-
.colors ⇒ Object
returns COLORS.
-
.cols ⇒ Object
Returns the number of columns on the screen.
-
.crmode ⇒ Object
Put the terminal into cbreak mode.
-
.curs_set(visibility) ⇒ Object
Sets Cursor Visibility.
-
.def_prog_mode ⇒ Object
Save the current terminal modes as the “program” state for use by the Curses.reset_prog_mode.
-
.delch ⇒ Object
Delete the character under the cursor.
-
.deleteln ⇒ Object
Delete the line under the cursor.
-
.doupdate ⇒ Object
Refreshes the windows and lines.
-
.echo ⇒ Object
Enables characters typed by the user to be echoed by Curses.getch as they are typed.
-
.erase ⇒ Object
Erase the screen.
-
.ESCDELAY ⇒ Object
Returns the total time, in milliseconds, for which curses will await a character sequence, e.g., a function key.
-
.ESCDELAY=(value) ⇒ Object
Sets the ESCDELAY to Integer
value. -
.flash ⇒ Object
Flashes the screen, for visual alarm on the terminal, if possible; otherwise it sounds the alert.
-
.get_char ⇒ Object
Read and returns a character or function key from the window.
- .get_key_modifiers ⇒ Object
-
.getch ⇒ Object
Read and returns a character from the window.
-
.getmouse ⇒ Object
Returns coordinates of the mouse.
-
.getstr ⇒ Object
This is equivalent to a series of Curses::Window.getch calls.
-
.has_colors? ⇒ Boolean
Returns
trueorfalsedepending on whether the terminal has color capabilities. -
.inch ⇒ Object
Returns the character at the current position.
-
.init_color(color, r, g, b) ⇒ Object
Changes the definition of a color.
-
.init_pair(pair, f, b) ⇒ Object
Changes the definition of a color-pair.
-
.init_screen ⇒ Object
Initialize a standard screen.
-
.insch(ch) ⇒ Object
Insert a character
ch, before the cursor. -
.insertln ⇒ Object
Inserts a line above the cursor, and the bottom line is lost.
-
.keyboard_encoding ⇒ Object
Returns the encoding for keyboard input.
-
.keyboard_encoding=(encoding) ⇒ Object
Sets the encoding for keyboard input.
-
.keyname(c) ⇒ Object
Returns the character string corresponding to key
c. -
.lines ⇒ Object
Returns the number of lines on the screen.
-
.mouseinterval(interval) ⇒ Object
The Curses.mouseinterval function sets the maximum time (in thousands of a second) that can elapse between press and release events for them to be recognized as a click.
-
.mousemask(mask) ⇒ Object
Returns the
maskof the reportable events. -
.nl ⇒ Object
Enable the underlying display device to translate the return key into newline on input, and whether it translates newline into return and line-feed on output (in either case, the call Curses.addch(‘n’) does the equivalent of return and line feed on the virtual screen).
-
.nocbreak ⇒ Object
Put the terminal into normal mode (out of cbreak mode).
-
.nocrmode ⇒ Object
Put the terminal into normal mode (out of cbreak mode).
-
.noecho ⇒ Object
Disables characters typed by the user to be echoed by Curses.getch as they are typed.
-
.nonl ⇒ Object
Disable the underlying display device to translate the return key into newline on input.
-
.noraw ⇒ Object
Put the terminal out of raw mode.
-
.pair_content(pair) ⇒ Object
Returns a 2 item Array, with the foreground and background color, in
pair. -
.pair_number(attrs) ⇒ Object
Returns the Fixnum color pair number of attributes
attrs. -
.raw ⇒ Object
Put the terminal into raw mode.
-
.refresh ⇒ Object
Refreshes the windows and lines.
-
.reset_prog_mode ⇒ Object
Reset the current terminal modes to the saved state by the Curses.def_prog_mode.
-
.resizeterm(lines, cols) ⇒ Object
Resize the current term to Fixnum
linesand Fixnumcols. -
.resizeterm(lines, cols) ⇒ Object
Resize the current term to Fixnum
linesand Fixnumcols. - .return_key_modifiers(flag) ⇒ Object
- .save_key_modifiers(flag) ⇒ Object
-
.scrl(num) ⇒ Object
Scrolls the current window Fixnum
numlines. -
.setpos(y, x) ⇒ Object
A setter for the position of the cursor, using coordinates
xandy. -
.setscrreg(top, bottom) ⇒ Object
call-seq: setscrreg(top, bottom).
-
.standend ⇒ Object
Enables the Normal display (no highlight).
-
.standout ⇒ Object
Enables the best highlighting mode of the terminal.
-
.start_color ⇒ Object
Initializes the color attributes, for terminals that support it.
-
.stdscr ⇒ Object
Initialize a standard screen.
-
.TABSIZE ⇒ Object
Returns the number of positions in a tab.
-
.TABSIZE=(value) ⇒ Object
Sets the TABSIZE to Integer
value. -
.terminal_encoding ⇒ Object
Returns the encoding for terminal output.
-
.terminal_encoding=(encoding) ⇒ Object
Sets the encoding for terminal output.
-
.timeout=(delay) ⇒ Object
Sets block and non-blocking reads for the window.
-
.unget_char(ch) ⇒ Object
Places
chback onto the input queue to be returned by the next call to Curses.get_char etc. -
.ungetch(ch) ⇒ Object
Places
chback onto the input queue to be returned by the next call to Curses.getch. -
.ungetmouse(mevent) ⇒ Object
It pushes a KEY_MOUSE event onto the input queue, and associates with that event the given state data and screen-relative character-cell coordinates.
-
.use_default_colors ⇒ Object
tells the curses library to use terminal’s default colors.
Class Method Details
.addch(ch) ⇒ Object
Add a character ch, with attributes, then advance the cursor.
see also the system manual for curs_addch(3)
772 773 774 775 776 777 778 |
# File 'ext/curses/curses.c', line 772
static VALUE
curses_addch(VALUE obj, VALUE ch)
{
curses_stdscr();
addch(OBJ2CHTYPE(ch));
return Qnil;
}
|
.addstr(str) ⇒ Object
add a string of characters str, to the window and advance cursor
802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'ext/curses/curses.c', line 802
static VALUE
curses_addstr(VALUE obj, VALUE str)
{
StringValue(str);
#if defined(HAVE_ADDNWSTR) && defined(_WIN32)
str = rb_str_export_to_enc(str, get_wide_encoding());
curses_stdscr();
if (!NIL_P(str)) {
addnwstr((wchar_t *)RSTRING_PTR(str), RSTRING_LEN(str) / sizeof(wchar_t));
}
#else
str = rb_str_export_to_enc(str, terminal_encoding);
curses_stdscr();
if (!NIL_P(str)) {
addstr(StringValueCStr(str));
}
#endif
return Qnil;
}
|
.assume_default_colors(fg, bg) ⇒ Object
tells which colors to paint for color pair 0.
see also the system manual for default_colors(3)
1170 1171 1172 1173 1174 1175 1176 |
# File 'ext/curses/curses.c', line 1170
static VALUE
curses_assume_default_colors(VALUE obj, VALUE fg, VALUE bg)
{
curses_stdscr();
assume_default_colors(NUM2INT(fg), NUM2INT(bg));
return Qnil;
}
|
.attroff(attrs) ⇒ Object
Turns off the named attributes attrs without affecting any others.
See also Curses::Window.attrset for additional information.
1060 1061 1062 1063 1064 1065 1066 |
# File 'ext/curses/curses.c', line 1060
static VALUE
curses_attroff(VALUE obj, VALUE attrs)
{
curses_stdscr();
return window_attroff(rb_stdscr,attrs);
/* return INT2FIX(attroff(NUM2INT(attrs))); */
}
|
.attron(attrs) ⇒ Object
Turns on the named attributes attrs without turning any other attributes on or off.
See also Curses::Window.attrset for additional information.
1077 1078 1079 1080 1081 1082 1083 |
# File 'ext/curses/curses.c', line 1077
static VALUE
curses_attron(VALUE obj, VALUE attrs)
{
curses_stdscr();
return window_attron(rb_stdscr,attrs);
/* return INT2FIX(attroff(NUM2INT(attrs))); */
}
|
.attrset(attrs) ⇒ Object
Sets the current attributes of the given window to attrs.
see also Curses::Window.attrset
1094 1095 1096 1097 1098 1099 1100 |
# File 'ext/curses/curses.c', line 1094
static VALUE
curses_attrset(VALUE obj, VALUE attrs)
{
curses_stdscr();
return window_attrset(rb_stdscr,attrs);
/* return INT2FIX(attroff(NUM2INT(attrs))); */
}
|
.beep ⇒ Object
Sounds an audible alarm on the terminal, if possible; otherwise it flashes the screen (visual bell).
see also Curses.flash
631 632 633 634 635 636 637 638 639 |
# File 'ext/curses/curses.c', line 631
static VALUE
curses_beep(VALUE obj)
{
#ifdef HAVE_BEEP
curses_stdscr();
beep();
#endif
return Qnil;
}
|
.bkgd(ch) ⇒ Object
Window background manipulation routines.
Set the background property of the current and then apply the character Integer ch setting to every character position in that window.
see also the system manual for curs_bkgd(3)
1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 |
# File 'ext/curses/curses.c', line 1136
static VALUE
curses_bkgd(VALUE obj, VALUE ch)
{
#ifdef HAVE_BKGD
curses_stdscr();
return (bkgd(OBJ2CHTYPE(ch)) == OK) ? Qtrue : Qfalse;
#else
return Qfalse;
#endif
}
|
.bkgdset(ch) ⇒ Object
Manipulate the background of the named window with character Integer ch
The background becomes a property of the character and moves with the character through any scrolling and insert/delete line/character operations.
see also the system manual for curs_bkgd(3)
1115 1116 1117 1118 1119 1120 1121 1122 1123 |
# File 'ext/curses/curses.c', line 1115
static VALUE
curses_bkgdset(VALUE obj, VALUE ch)
{
#ifdef HAVE_BKGDSET
curses_stdscr();
bkgdset(OBJ2CHTYPE(ch));
#endif
return Qnil;
}
|
.can_change_color? ⇒ Boolean
Returns true or false depending on whether the terminal can change color attributes
1348 1349 1350 1351 1352 1353 |
# File 'ext/curses/curses.c', line 1348
static VALUE
curses_can_change_color(VALUE obj)
{
curses_stdscr();
return can_change_color() ? Qtrue : Qfalse;
}
|
.cbreak ⇒ Object
Put the terminal into cbreak mode.
Normally, the tty driver buffers typed characters until a newline or carriage return is typed. The Curses.cbreak routine disables line buffering and erase/kill character-processing (interrupt and flow control characters are unaffected), making characters typed by the user immediately available to the program.
The Curses.nocbreak routine returns the terminal to normal (cooked) mode.
Initially the terminal may or may not be in cbreak mode, as the mode is inherited; therefore, a program should call Curses.cbreak or Curses.nocbreak explicitly. Most interactive programs using curses set the cbreak mode. Note that Curses.cbreak overrides Curses.raw.
see also Curses.raw
562 563 564 565 566 567 568 |
# File 'ext/curses/curses.c', line 562
static VALUE
curses_cbreak(VALUE obj)
{
curses_stdscr();
cbreak();
return Qnil;
}
|
.clear ⇒ Object
Clears every position on the screen completely, so that a subsequent call by Curses.refresh for the screen/window will be repainted from scratch.
403 404 405 406 407 408 409 |
# File 'ext/curses/curses.c', line 403
static VALUE
curses_clear(VALUE obj)
{
curses_stdscr();
wclear(stdscr);
return Qnil;
}
|
.close_screen ⇒ Object
A program should always call Curses.close_screen before exiting or escaping from curses mode temporarily. This routine restores tty modes, moves the cursor to the lower left-hand corner of the screen and resets the terminal into the proper non-visual mode.
Calling Curses.refresh or Curses.doupdate after a temporary escape causes the program to resume visual mode.
343 344 345 346 347 348 349 350 351 352 353 |
# File 'ext/curses/curses.c', line 343
static VALUE
curses_close_screen(VALUE self)
{
curses_stdscr();
#ifdef HAVE_ISENDWIN
if (!isendwin())
#endif
endwin();
rb_stdscr = 0;
return Qnil;
}
|
.closed? ⇒ Boolean
Returns true if the window/screen has been closed, without any subsequent Curses.refresh calls, returns false otherwise.
383 384 385 386 387 388 389 390 391 |
# File 'ext/curses/curses.c', line 383
static VALUE
curses_closed(VALUE self)
{
curses_stdscr();
if (isendwin()) {
return Qtrue;
}
return Qfalse;
}
|
.clrtoeol ⇒ Object
Clears to the end of line, that the cursor is currently on.
433 434 435 436 437 438 439 |
# File 'ext/curses/curses.c', line 433
static VALUE
curses_clrtoeol(VALUE self)
{
curses_stdscr();
clrtoeol();
return Qnil;
}
|
.color_content(color) ⇒ Object
Returns an 3 item Array of the RGB values in color
1376 1377 1378 1379 1380 1381 1382 1383 1384 |
# File 'ext/curses/curses.c', line 1376
static VALUE
curses_color_content(VALUE obj, VALUE color)
{
short r,g,b;
curses_stdscr();
color_content(NUM2INT(color),&r,&g,&b);
return rb_ary_new3(3,INT2FIX(r),INT2FIX(g),INT2FIX(b));
}
|
.color_pair(attrs) ⇒ Object
Sets the color pair attributes to attrs.
This should be equivalent to Curses.attrset(COLOR_PAIR(attrs))
TODO: validate that equivalency
1429 1430 1431 1432 1433 |
# File 'ext/curses/curses.c', line 1429
static VALUE
curses_color_pair(VALUE obj, VALUE attrs)
{
return INT2FIX(COLOR_PAIR(NUM2INT(attrs)));
}
|
.color_pairs ⇒ Object
Returns the COLOR_PAIRS available, if the curses library supports it.
1393 1394 1395 1396 1397 |
# File 'ext/curses/curses.c', line 1393
static VALUE
curses_color_pairs(VALUE obj)
{
return INT2FIX(COLOR_PAIRS);
}
|
.colors ⇒ Object
returns COLORS
1361 1362 1363 1364 1365 |
# File 'ext/curses/curses.c', line 1361
static VALUE
curses_colors(VALUE obj)
{
return INT2FIX(COLORS);
}
|
.cols ⇒ Object
Returns the number of columns on the screen
973 974 975 976 977 |
# File 'ext/curses/curses.c', line 973
static VALUE
curses_cols(VALUE self)
{
return INT2FIX(COLS);
}
|
.crmode ⇒ Object
Put the terminal into cbreak mode.
Normally, the tty driver buffers typed characters until a newline or carriage return is typed. The Curses.cbreak routine disables line buffering and erase/kill character-processing (interrupt and flow control characters are unaffected), making characters typed by the user immediately available to the program.
The Curses.nocbreak routine returns the terminal to normal (cooked) mode.
Initially the terminal may or may not be in cbreak mode, as the mode is inherited; therefore, a program should call Curses.cbreak or Curses.nocbreak explicitly. Most interactive programs using curses set the cbreak mode. Note that Curses.cbreak overrides Curses.raw.
see also Curses.raw
562 563 564 565 566 567 568 |
# File 'ext/curses/curses.c', line 562
static VALUE
curses_cbreak(VALUE obj)
{
curses_stdscr();
cbreak();
return Qnil;
}
|
.curs_set(visibility) ⇒ Object
Sets Cursor Visibility. 0: invisible 1: visible 2: very visible
988 989 990 991 992 993 994 995 996 997 998 |
# File 'ext/curses/curses.c', line 988
static VALUE
curses_curs_set(VALUE obj, VALUE visibility)
{
#ifdef HAVE_CURS_SET
int n;
curses_stdscr();
return (n = curs_set(NUM2INT(visibility)) != ERR) ? INT2FIX(n) : Qnil;
#else
return Qnil;
#endif
}
|
.def_prog_mode ⇒ Object
Save the current terminal modes as the “program” state for use by the Curses.reset_prog_mode
This is done automatically by Curses.init_screen
1643 1644 1645 1646 1647 1648 |
# File 'ext/curses/curses.c', line 1643
static VALUE
curses_def_prog_mode(VALUE obj)
{
curses_stdscr();
return def_prog_mode() == OK ? Qtrue : Qfalse;
}
|
.delch ⇒ Object
Delete the character under the cursor
891 892 893 894 895 896 897 |
# File 'ext/curses/curses.c', line 891
static VALUE
curses_delch(VALUE obj)
{
curses_stdscr();
delch();
return Qnil;
}
|
.deleteln ⇒ Object
Delete the line under the cursor.
905 906 907 908 909 910 911 912 913 |
# File 'ext/curses/curses.c', line 905
static VALUE
curses_deleteln(VALUE obj)
{
curses_stdscr();
#if defined(HAVE_DELETELN) || defined(deleteln)
deleteln();
#endif
return Qnil;
}
|
.doupdate ⇒ Object
Refreshes the windows and lines.
Curses.doupdate allows multiple updates with more efficiency than Curses.refresh alone.
463 464 465 466 467 468 469 470 471 472 473 |
# File 'ext/curses/curses.c', line 463
static VALUE
curses_doupdate(VALUE obj)
{
curses_stdscr();
#ifdef HAVE_DOUPDATE
doupdate();
#else
refresh();
#endif
return Qnil;
}
|
.echo ⇒ Object
Enables characters typed by the user to be echoed by Curses.getch as they are typed.
481 482 483 484 485 486 487 |
# File 'ext/curses/curses.c', line 481
static VALUE
curses_echo(VALUE obj)
{
curses_stdscr();
echo();
return Qnil;
}
|
.erase ⇒ Object
Erase the screen.
417 418 419 420 421 422 423 |
# File 'ext/curses/curses.c', line 417
static VALUE
curses_erase(VALUE obj)
{
curses_stdscr();
werase(stdscr);
return Qnil;
}
|
.ESCDELAY ⇒ Object
Returns the total time, in milliseconds, for which curses will await a character sequence, e.g., a function key
1232 1233 1234 1235 1236 |
# File 'ext/curses/curses.c', line 1232
static VALUE
curses_escdelay_get(VALUE obj)
{
return INT2NUM(ESCDELAY);
}
|
.ESCDELAY=(value) ⇒ Object
Sets the ESCDELAY to Integer value
1217 1218 1219 1220 1221 1222 |
# File 'ext/curses/curses.c', line 1217
static VALUE
curses_escdelay_set(VALUE obj, VALUE val)
{
ESCDELAY = NUM2INT(val);
return INT2NUM(ESCDELAY);
}
|
.flash ⇒ Object
Flashes the screen, for visual alarm on the terminal, if possible; otherwise it sounds the alert.
see also Curses.beep
649 650 651 652 653 654 655 656 657 |
# File 'ext/curses/curses.c', line 649
static VALUE
curses_flash(VALUE obj)
{
#ifdef HAVE_FLASH
curses_stdscr();
flash();
#endif
return Qnil;
}
|
.get_char ⇒ Object
Read and returns a character or function key from the window. A single or multibyte character is represented by a String, and a function key is represented by an Integer. Returns nil if no input is ready.
See Curses::Key to all the function KEY_* available
4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 |
# File 'ext/curses/curses.c', line 4535
static VALUE
curses_get_char(VALUE obj)
{
#ifdef HAVE_GET_WCH
struct get_wch_arg arg;
curses_stdscr();
rb_thread_call_without_gvl(get_wch_func, &arg, RUBY_UBF_IO, 0);
switch (arg.retval) {
case OK:
return keyboard_uint_chr(arg.ch);
case KEY_CODE_YES:
return key_code_value(arg.ch);
}
return Qnil;
#else
int c;
curses_stdscr();
rb_thread_call_without_gvl(getch_func, &c, RUBY_UBF_IO, 0);
if (c > 0xff) {
return INT2NUM(c);
}
else if (c >= 0) {
return keyboard_uint_chr(c);
}
else {
return Qnil;
}
#endif
}
|
.get_key_modifiers ⇒ Object
4632 4633 4634 4635 4636 |
# File 'ext/curses/curses.c', line 4632
static VALUE
curses_get_key_modifiers(VALUE obj)
{
return ULONG2NUM(PDC_get_key_modifiers());
}
|
.getch ⇒ Object
Read and returns a character from the window.
See Curses::Key to all the function KEY_* available
838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 |
# File 'ext/curses/curses.c', line 838
static VALUE
curses_getch(VALUE obj)
{
int c;
curses_stdscr();
rb_thread_call_without_gvl(getch_func, &c, RUBY_UBF_IO, 0);
if (c == EOF) return Qnil;
if (rb_isprint(c)) {
char ch = (char)c;
return rb_external_str_new_with_enc(&ch, 1, keyboard_encoding);
}
return UINT2NUM(c);
}
|
.getmouse ⇒ Object
Returns coordinates of the mouse.
This will read and pop the mouse event data off the queue
See the BUTTON*, ALL_MOUSE_EVENTS and REPORT_MOUSE_POSITION constants, to examine the mask of the event
1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 |
# File 'ext/curses/curses.c', line 1498
static VALUE
curses_getmouse(VALUE obj)
{
struct mousedata *mdata;
VALUE val;
curses_stdscr();
val = TypedData_Make_Struct(cMouseEvent,struct mousedata,
&mousedata_type,mdata);
mdata->mevent = (MEVENT*)xmalloc(sizeof(MEVENT));
return (getmouse(mdata->mevent) == OK) ? val : Qnil;
}
|
.getstr ⇒ Object
This is equivalent to a series of Curses::Window.getch calls
875 876 877 878 879 880 881 882 883 |
# File 'ext/curses/curses.c', line 875
static VALUE
curses_getstr(VALUE obj)
{
char rtn[GETSTR_BUF_SIZE];
curses_stdscr();
rb_thread_call_without_gvl(getstr_func, rtn, RUBY_UBF_IO, 0);
return rb_external_str_new_with_enc(rtn, strlen(rtn), keyboard_encoding);
}
|
.has_colors? ⇒ Boolean
Returns true or false depending on whether the terminal has color capabilities.
1336 1337 1338 1339 1340 1341 |
# File 'ext/curses/curses.c', line 1336
static VALUE
curses_has_colors(VALUE obj)
{
curses_stdscr();
return has_colors() ? Qtrue : Qfalse;
}
|
.inch ⇒ Object
Returns the character at the current position.
757 758 759 760 761 762 |
# File 'ext/curses/curses.c', line 757
static VALUE
curses_inch(VALUE obj)
{
curses_stdscr();
return CHTYPE2NUM(inch());
}
|
.init_color(color, r, g, b) ⇒ Object
Changes the definition of a color. It takes four arguments:
-
the number of the color to be changed,
color -
the amount of red,
r -
the amount of green,
g -
the amount of blue,
b
The value of the first argument must be between 0 and COLORS. (See the section Colors for the default color index.) Each of the last three arguments must be a value between 0 and 1000. When Curses.init_color is used, all occurrences of that color on the screen immediately change to the new definition.
1322 1323 1324 1325 1326 1327 1328 1329 |
# File 'ext/curses/curses.c', line 1322
static VALUE
curses_init_color(VALUE obj, VALUE color, VALUE r, VALUE g, VALUE b)
{
/* may have to raise exception on ERR */
curses_stdscr();
return (init_color(NUM2INT(color),NUM2INT(r),
NUM2INT(g),NUM2INT(b)) == OK) ? Qtrue : Qfalse;
}
|
.init_pair(pair, f, b) ⇒ Object
Changes the definition of a color-pair.
It takes three arguments: the number of the color-pair to be changed pair, the foreground color number f, and the background color number b.
If the color-pair was previously initialized, the screen is refreshed and all occurrences of that color-pair are changed to the new definition.
1298 1299 1300 1301 1302 1303 1304 |
# File 'ext/curses/curses.c', line 1298
static VALUE
curses_init_pair(VALUE obj, VALUE pair, VALUE f, VALUE b)
{
/* may have to raise exception on ERR */
curses_stdscr();
return (init_pair(NUM2INT(pair),NUM2INT(f),NUM2INT(b)) == OK) ? Qtrue : Qfalse;
}
|
.init_screen ⇒ Object
Initialize a standard screen
see also Curses.stdscr
304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'ext/curses/curses.c', line 304
static VALUE
curses_init_screen(VALUE self)
{
if (rb_stdscr) return rb_stdscr;
initscr();
if (stdscr == 0) {
rb_raise(rb_eRuntimeError, "can't initialize curses");
}
rb_set_end_proc(curses_finalize, 0);
clear();
rb_stdscr = prep_window(cWindow, stdscr);
return rb_stdscr;
}
|
.insch(ch) ⇒ Object
Insert a character ch, before the cursor.
787 788 789 790 791 792 793 |
# File 'ext/curses/curses.c', line 787
static VALUE
curses_insch(VALUE obj, VALUE ch)
{
curses_stdscr();
insch(OBJ2CHTYPE(ch));
return Qnil;
}
|
.insertln ⇒ Object
Inserts a line above the cursor, and the bottom line is lost
921 922 923 924 925 926 927 928 929 |
# File 'ext/curses/curses.c', line 921
static VALUE
curses_insertln(VALUE obj)
{
curses_stdscr();
#if defined(HAVE_INSERTLN) || defined(insertln)
insertln();
#endif
return Qnil;
}
|
.keyboard_encoding ⇒ Object
Returns the encoding for keyboard input.
4411 4412 4413 4414 4415 |
# File 'ext/curses/curses.c', line 4411
static VALUE
curses_get_keyboard_encoding(VALUE obj)
{
return rb_enc_from_encoding(keyboard_encoding);
}
|
.keyboard_encoding=(encoding) ⇒ Object
Sets the encoding for keyboard input.
4423 4424 4425 4426 4427 4428 |
# File 'ext/curses/curses.c', line 4423
static VALUE
curses_set_keyboard_encoding(VALUE obj, VALUE enc)
{
keyboard_encoding = rb_to_encoding(enc);
return enc;
}
|
.keyname(c) ⇒ Object
Returns the character string corresponding to key c
937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 |
# File 'ext/curses/curses.c', line 937
static VALUE
curses_keyname(VALUE obj, VALUE c)
{
#ifdef HAVE_KEYNAME
int cc = curses_char(c);
const char *name;
curses_stdscr();
name = keyname(cc);
if (name) {
return rb_str_new_cstr(name);
}
else {
return Qnil;
}
#else
return Qnil;
#endif
}
|
.lines ⇒ Object
Returns the number of lines on the screen
962 963 964 965 966 |
# File 'ext/curses/curses.c', line 962
static VALUE
curses_lines(VALUE self)
{
return INT2FIX(LINES);
}
|
.mouseinterval(interval) ⇒ Object
The Curses.mouseinterval function sets the maximum time (in thousands of a second) that can elapse between press and release events for them to be recognized as a click.
Use Curses.mouseinterval(0) to disable click resolution. This function returns the previous interval value.
Use Curses.mouseinterval(-1) to obtain the interval without altering it.
The default is one sixth of a second.
1545 1546 1547 1548 1549 1550 |
# File 'ext/curses/curses.c', line 1545
static VALUE
curses_mouseinterval(VALUE obj, VALUE interval)
{
curses_stdscr();
return mouseinterval(NUM2INT(interval)) ? Qtrue : Qfalse;
}
|
.mousemask(mask) ⇒ Object
Returns the mask of the reportable events
1558 1559 1560 1561 1562 1563 |
# File 'ext/curses/curses.c', line 1558
static VALUE
curses_mousemask(VALUE obj, VALUE mask)
{
curses_stdscr();
return ULONG2NUM(mousemask(NUM2UINT(mask),NULL));
}
|
.nl ⇒ Object
Enable the underlying display device to translate the return key into newline on input, and whether it translates newline into return and line-feed on output (in either case, the call Curses.addch(‘n’) does the equivalent of return and line feed on the virtual screen).
Initially, these translations do occur. If you disable them using Curses.nonl, curses will be able to make better use of the line-feed capability, resulting in faster cursor motion. Also, curses will then be able to detect the return key.
599 600 601 602 603 604 605 |
# File 'ext/curses/curses.c', line 599
static VALUE
curses_nl(VALUE obj)
{
curses_stdscr();
nl();
return Qnil;
}
|
.nocbreak ⇒ Object
Put the terminal into normal mode (out of cbreak mode).
See Curses.cbreak for more detail.
577 578 579 580 581 582 583 |
# File 'ext/curses/curses.c', line 577
static VALUE
curses_nocbreak(VALUE obj)
{
curses_stdscr();
nocbreak();
return Qnil;
}
|
.nocrmode ⇒ Object
Put the terminal into normal mode (out of cbreak mode).
See Curses.cbreak for more detail.
577 578 579 580 581 582 583 |
# File 'ext/curses/curses.c', line 577
static VALUE
curses_nocbreak(VALUE obj)
{
curses_stdscr();
nocbreak();
return Qnil;
}
|
.noecho ⇒ Object
Disables characters typed by the user to be echoed by Curses.getch as they are typed.
495 496 497 498 499 500 501 |
# File 'ext/curses/curses.c', line 495
static VALUE
curses_noecho(VALUE obj)
{
curses_stdscr();
noecho();
return Qnil;
}
|
.nonl ⇒ Object
Disable the underlying display device to translate the return key into newline on input
See Curses.nl for more detail
615 616 617 618 619 620 621 |
# File 'ext/curses/curses.c', line 615
static VALUE
curses_nonl(VALUE obj)
{
curses_stdscr();
nonl();
return Qnil;
}
|
.noraw ⇒ Object
Put the terminal out of raw mode.
see Curses.raw for more detail
532 533 534 535 536 537 538 |
# File 'ext/curses/curses.c', line 532
static VALUE
curses_noraw(VALUE obj)
{
curses_stdscr();
noraw();
return Qnil;
}
|
.pair_content(pair) ⇒ Object
Returns a 2 item Array, with the foreground and background color, in pair
1409 1410 1411 1412 1413 1414 1415 1416 1417 |
# File 'ext/curses/curses.c', line 1409
static VALUE
curses_pair_content(VALUE obj, VALUE pair)
{
short f,b;
curses_stdscr();
pair_content(NUM2INT(pair),&f,&b);
return rb_ary_new3(2,INT2FIX(f),INT2FIX(b));
}
|
.pair_number(attrs) ⇒ Object
Returns the Fixnum color pair number of attributes attrs.
1441 1442 1443 1444 1445 1446 |
# File 'ext/curses/curses.c', line 1441
static VALUE
curses_pair_number(VALUE obj, VALUE attrs)
{
curses_stdscr();
return INT2FIX(PAIR_NUMBER(NUM2LONG(attrs)));
}
|
.raw ⇒ Object
Put the terminal into raw mode.
Raw mode is similar to Curses.cbreak mode, in that characters typed are immediately passed through to the user program.
The differences are that in raw mode, the interrupt, quit, suspend, and flow control characters are all passed through uninterpreted, instead of generating a signal. The behavior of the BREAK key depends on other bits in the tty driver that are not set by curses.
517 518 519 520 521 522 523 |
# File 'ext/curses/curses.c', line 517
static VALUE
curses_raw(VALUE obj)
{
curses_stdscr();
raw();
return Qnil;
}
|
.refresh ⇒ Object
Refreshes the windows and lines.
447 448 449 450 451 452 453 |
# File 'ext/curses/curses.c', line 447
static VALUE
curses_refresh(VALUE obj)
{
curses_stdscr();
refresh();
return Qnil;
}
|
.reset_prog_mode ⇒ Object
Reset the current terminal modes to the saved state by the Curses.def_prog_mode
This is done automatically by Curses.close_screen
1662 1663 1664 1665 1666 1667 |
# File 'ext/curses/curses.c', line 1662
static VALUE
curses_reset_prog_mode(VALUE obj)
{
curses_stdscr();
return reset_prog_mode() == OK ? Qtrue : Qfalse;
}
|
.resizeterm(lines, cols) ⇒ Object
Resize the current term to Fixnum lines and Fixnum cols
1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 |
# File 'ext/curses/curses.c', line 1256
static VALUE
curses_resizeterm(VALUE obj, VALUE lin, VALUE col)
{
#if defined(HAVE_RESIZETERM)
curses_stdscr();
return (resizeterm(NUM2INT(lin),NUM2INT(col)) == OK) ? Qtrue : Qfalse;
#else
return Qnil;
#endif
}
|
.resizeterm(lines, cols) ⇒ Object
Resize the current term to Fixnum lines and Fixnum cols
1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 |
# File 'ext/curses/curses.c', line 1256
static VALUE
curses_resizeterm(VALUE obj, VALUE lin, VALUE col)
{
#if defined(HAVE_RESIZETERM)
curses_stdscr();
return (resizeterm(NUM2INT(lin),NUM2INT(col)) == OK) ? Qtrue : Qfalse;
#else
return Qnil;
#endif
}
|
.return_key_modifiers(flag) ⇒ Object
4638 4639 4640 4641 4642 |
# File 'ext/curses/curses.c', line 4638
static VALUE
curses_return_key_modifiers(VALUE obj, VALUE flag)
{
return INT2NUM(PDC_return_key_modifiers(RTEST(flag)));
}
|
.save_key_modifiers(flag) ⇒ Object
4644 4645 4646 4647 4648 |
# File 'ext/curses/curses.c', line 4644
static VALUE
curses_save_key_modifiers(VALUE obj, VALUE flag)
{
return INT2NUM(PDC_save_key_modifiers(RTEST(flag)));
}
|
.scrl(num) ⇒ Object
Scrolls the current window Fixnum num lines. The current cursor position is not changed.
For positive num, it scrolls up.
For negative num, it scrolls down.
1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 |
# File 'ext/curses/curses.c', line 1012
static VALUE
curses_scrl(VALUE obj, VALUE n)
{
/* may have to raise exception on ERR */
#ifdef HAVE_SCRL
curses_stdscr();
return (scrl(NUM2INT(n)) == OK) ? Qtrue : Qfalse;
#else
return Qfalse;
#endif
}
|
.setpos(y, x) ⇒ Object
A setter for the position of the cursor, using coordinates x and y
710 711 712 713 714 715 716 |
# File 'ext/curses/curses.c', line 710
static VALUE
curses_setpos(VALUE obj, VALUE y, VALUE x)
{
curses_stdscr();
move(NUM2INT(y), NUM2INT(x));
return Qnil;
}
|
.setscrreg(top, bottom) ⇒ Object
call-seq:
setscrreg(top, bottom)
Set a software scrolling region in a window. top and bottom are lines numbers of the margin.
If this option and Curses.scrollok are enabled, an attempt to move off the bottom margin line causes all lines in the scrolling region to scroll one line in the direction of the first line. Only the text of the window is scrolled.
1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 |
# File 'ext/curses/curses.c', line 1039
static VALUE
curses_setscrreg(VALUE obj, VALUE top, VALUE bottom)
{
/* may have to raise exception on ERR */
#ifdef HAVE_SETSCRREG
curses_stdscr();
return (setscrreg(NUM2INT(top), NUM2INT(bottom)) == OK) ? Qtrue : Qfalse;
#else
return Qfalse;
#endif
}
|
.standend ⇒ Object
Enables the Normal display (no highlight)
This is equivalent to Curses.attron(A_NORMAL)
see also Curses::Window.attrset for additional information.
744 745 746 747 748 749 750 |
# File 'ext/curses/curses.c', line 744
static VALUE
curses_standend(VALUE obj)
{
curses_stdscr();
standend();
return Qnil;
}
|
.standout ⇒ Object
Enables the best highlighting mode of the terminal.
This is equivalent to Curses:Window.attron(A_STANDOUT)
see also Curses::Window.attrset additional information
727 728 729 730 731 732 733 |
# File 'ext/curses/curses.c', line 727
static VALUE
curses_standout(VALUE obj)
{
curses_stdscr();
standout();
return Qnil;
}
|
.start_color ⇒ Object
Initializes the color attributes, for terminals that support it.
This must be called, in order to use color attributes. It is good practice to call it just after Curses.init_screen
1276 1277 1278 1279 1280 1281 1282 |
# File 'ext/curses/curses.c', line 1276
static VALUE
curses_start_color(VALUE obj)
{
/* may have to raise exception on ERR */
curses_stdscr();
return (start_color() == OK) ? Qtrue : Qfalse;
}
|
.stdscr ⇒ Object
Initialize a standard screen
see also Curses.stdscr
304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'ext/curses/curses.c', line 304
static VALUE
curses_init_screen(VALUE self)
{
if (rb_stdscr) return rb_stdscr;
initscr();
if (stdscr == 0) {
rb_raise(rb_eRuntimeError, "can't initialize curses");
}
rb_set_end_proc(curses_finalize, 0);
clear();
rb_stdscr = prep_window(cWindow, stdscr);
return rb_stdscr;
}
|
.TABSIZE ⇒ Object
Returns the number of positions in a tab.
1202 1203 1204 1205 1206 |
# File 'ext/curses/curses.c', line 1202
static VALUE
curses_tabsize_get(VALUE ojb)
{
return INT2NUM(TABSIZE);
}
|
.TABSIZE=(value) ⇒ Object
Sets the TABSIZE to Integer value
1188 1189 1190 1191 1192 1193 |
# File 'ext/curses/curses.c', line 1188
static VALUE
curses_tabsize_set(VALUE obj, VALUE val)
{
TABSIZE = NUM2INT(val);
return INT2NUM(TABSIZE);
}
|
.terminal_encoding ⇒ Object
Returns the encoding for terminal output.
4436 4437 4438 4439 4440 |
# File 'ext/curses/curses.c', line 4436
static VALUE
curses_get_terminal_encoding(VALUE obj)
{
return rb_enc_from_encoding(terminal_encoding);
}
|
.terminal_encoding=(encoding) ⇒ Object
Sets the encoding for terminal output.
4448 4449 4450 4451 4452 4453 |
# File 'ext/curses/curses.c', line 4448
static VALUE
curses_set_terminal_encoding(VALUE obj, VALUE enc)
{
terminal_encoding = rb_to_encoding(enc);
return enc;
}
|
.timeout=(delay) ⇒ Object
Sets block and non-blocking reads for the window.
-
If delay is negative, blocking read is used (i.e., waits indefinitely for input).
-
If delay is zero, then non-blocking read is used (i.e., read returns ERR if no input is waiting).
-
If delay is positive, then read blocks for delay milliseconds, and returns ERR if there is still no input.
1623 1624 1625 1626 1627 1628 1629 |
# File 'ext/curses/curses.c', line 1623
static VALUE
curses_timeout(VALUE obj, VALUE delay)
{
curses_stdscr();
timeout(NUM2INT(delay));
return Qnil;
}
|
.unget_char(ch) ⇒ Object
Places ch back onto the input queue to be returned by the next call to Curses.get_char etc.
There is just one input queue for all windows.
4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 |
# File 'ext/curses/curses.c', line 4464
static VALUE
curses_unget_char(VALUE obj, VALUE ch)
{
ID id_ord;
unsigned int c;
curses_stdscr();
if (FIXNUM_P(ch)) {
ungetch(NUM2UINT(ch));
}
else {
StringValue(ch);
CONST_ID(id_ord, "ord");
c = NUM2UINT(rb_funcall(ch, id_ord, 0));
#ifdef HAVE_UNGET_WCH
unget_wch(c);
#else
if (c > 0xff) {
rb_raise(rb_eRangeError, "Out of range: %u", c);
}
ungetch(c);
#endif
}
return Qnil;
}
|
.ungetch(ch) ⇒ Object
Places ch back onto the input queue to be returned by the next call to Curses.getch.
There is just one input queue for all windows.
690 691 692 693 694 695 696 697 |
# File 'ext/curses/curses.c', line 690
static VALUE
curses_ungetch(VALUE obj, VALUE ch)
{
int c = curses_char(ch);
curses_stdscr();
ungetch(c);
return Qnil;
}
|
.ungetmouse(mevent) ⇒ Object
It pushes a KEY_MOUSE event onto the input queue, and associates with that event the given state data and screen-relative character-cell coordinates.
The Curses.ungetmouse function behaves analogously to Curses.ungetch.
1519 1520 1521 1522 1523 1524 1525 1526 1527 |
# File 'ext/curses/curses.c', line 1519
static VALUE
curses_ungetmouse(VALUE obj, VALUE mevent)
{
struct mousedata *mdata;
curses_stdscr();
GetMOUSE(mevent,mdata);
return (ungetmouse(mdata->mevent) == OK) ? Qtrue : Qfalse;
}
|
.use_default_colors ⇒ Object
tells the curses library to use terminal’s default colors.
see also the system manual for default_colors(3)
1153 1154 1155 1156 1157 1158 1159 |
# File 'ext/curses/curses.c', line 1153
static VALUE
curses_use_default_colors(VALUE obj)
{
curses_stdscr();
use_default_colors();
return Qnil;
}
|