Method: Curses.bkgd
- Defined in:
- ext/curses/curses.c
.bkgd(ch) ⇒ Object
Window background manipulation routines.
Set the background property of the current and then apply the character Integer ch setting to every character position in that window.
see also the system manual for curs_bkgd(3)
1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 |
# File 'ext/curses/curses.c', line 1157 static VALUE curses_bkgd(VALUE obj, VALUE ch) { #ifdef HAVE_BKGD curses_stdscr(); return (bkgd(OBJ2CHTYPE(ch)) == OK) ? Qtrue : Qfalse; #else return Qfalse; #endif } |