Method: Curses.bkgdset
- Defined in:
- ext/curses/curses.c
.bkgdset(ch) ⇒ Object
Manipulate the background of the named window with character Integer ch
The background becomes a property of the character and moves with the character through any scrolling and insert/delete line/character operations.
see also the system manual for curs_bkgd(3)
1136 1137 1138 1139 1140 1141 1142 1143 1144 |
# File 'ext/curses/curses.c', line 1136 static VALUE curses_bkgdset(VALUE obj, VALUE ch) { #ifdef HAVE_BKGDSET curses_stdscr(); bkgdset(OBJ2CHTYPE(ch)); #endif return Qnil; } |