Method: Curses.flushinp
- Defined in:
- ext/curses/curses.c
.flushinp ⇒ Object
The flushinp routine throws away any typeahead that has been typed by the user and has not yet been read by the program.
636 637 638 639 640 641 642 |
# File 'ext/curses/curses.c', line 636 static VALUE curses_flushinp(VALUE obj) { curses_stdscr(); flushinp(); return Qnil; } |