Method: Curses.start_color
- Defined in:
- ext/curses/curses.c
.start_color ⇒ Object
Initializes the color attributes, for terminals that support it.
This must be called, in order to use color attributes. It is good practice to call it just after Curses.init_screen
1297 1298 1299 1300 1301 1302 1303 |
# File 'ext/curses/curses.c', line 1297 static VALUE curses_start_color(VALUE obj) { /* may have to raise exception on ERR */ curses_stdscr(); return (start_color() == OK) ? Qtrue : Qfalse; } |