Method: Curses.timeout=
- Defined in:
- ext/curses/curses.c
.timeout=(delay) ⇒ Object
Sets block and non-blocking reads for the window.
-
If delay is negative, blocking read is used (i.e., waits indefinitely for input).
-
If delay is zero, then non-blocking read is used (i.e., read returns ERR if no input is waiting).
-
If delay is positive, then read blocks for delay milliseconds, and returns ERR if there is still no input.
1644 1645 1646 1647 1648 1649 1650 |
# File 'ext/curses/curses.c', line 1644 static VALUE curses_timeout(VALUE obj, VALUE delay) { curses_stdscr(); timeout(NUM2INT(delay)); return Qnil; } |