Method: Curses.ungetch
- Defined in:
- ext/curses/curses.c
.ungetch(ch) ⇒ Object
Places ch back onto the input queue to be returned by the next call to Curses.getch.
There is just one input queue for all windows.
711 712 713 714 715 716 717 718 |
# File 'ext/curses/curses.c', line 711 static VALUE curses_ungetch(VALUE obj, VALUE ch) { int c = curses_char(ch); curses_stdscr(); ungetch(c); return Qnil; } |