Method: Curses.ungetmouse
- Defined in:
- ext/curses/curses.c
.ungetmouse(mevent) ⇒ Object
It pushes a KEY_MOUSE event onto the input queue, and associates with that event the given state data and screen-relative character-cell coordinates.
The Curses.ungetmouse function behaves analogously to Curses.ungetch.
1540 1541 1542 1543 1544 1545 1546 1547 1548 |
# File 'ext/curses/curses.c', line 1540 static VALUE curses_ungetmouse(VALUE obj, VALUE mevent) { struct mousedata *mdata; curses_stdscr(); GetMOUSE(mevent,mdata); return (ungetmouse(mdata->mevent) == OK) ? Qtrue : Qfalse; } |