Method: Curses::Window#scrollok
- Defined in:
- ext/curses/curses.c
#scrollok(bool) ⇒ Object
Controls what happens when the cursor of a window is moved off the edge of the window or scrolling region, either as a result of a newline action on the bottom line, or typing the last character of the last line.
If disabled, (bool is false), the cursor is left on the bottom line.
If enabled, (bool is true), the window is scrolled up one line (Note that to get the physical scrolling effect on the terminal, it is also necessary to call Curses::Window.idlok)
2654 2655 2656 2657 2658 2659 2660 2661 2662 |
# File 'ext/curses/curses.c', line 2654 static VALUE window_scrollok(VALUE obj, VALUE bf) { struct windata *winp; GetWINDOW(obj, winp); scrollok(winp->window, RTEST(bf) ? TRUE : FALSE); return Qnil; } |