Class: Curses::Window

Inherits:
Data
  • Object
show all
Defined in:
ext/curses/curses.c,
ext/curses/curses.c

Overview

Description

The means by which to create and manage frames or windows. While there may be more than one window at a time, only one window will receive input.

Usage

require "curses"

Curses.init_screen

my_str = "LOOK! PONIES!"

height, width = 12, my_str.length + 10
top, left = (Curses.lines - height) / 2, (Curses.cols - width) / 2
bwin = Curses::Window.new(height, width, top, left)
bwin.box("\\", "/")
bwin.refresh

win = bwin.subwin(height - 4, width - 4, top + 2, left + 2)
win.setpos(2, 3)
win.addstr(my_str)
# or even
win << "\nOH REALLY?"
win << "\nYES!! " + my_str
win.refresh
win.getch
win.close

Direct Known Subclasses

Pad

Instance Method Summary collapse

Constructor Details

#new(height, width, top, left) ⇒ Object

Construct a new Curses::Window with constraints of height lines, width columns, begin at top line, and begin left most column.

A new window using full screen is called as Curses::Window.new(0,0,0,0)



1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
# File 'ext/curses/curses.c', line 1680

static VALUE
window_initialize(VALUE obj, VALUE h, VALUE w, VALUE top, VALUE left)
{
    struct windata *winp;
    WINDOW *window;

    curses_init_screen();
    TypedData_Get_Struct(obj, struct windata, &windata_type, winp);
    if (winp->window) delwin(winp->window);
    window = newwin(NUM2INT(h), NUM2INT(w), NUM2INT(top), NUM2INT(left));
    wclear(window);
    winp->window = window;

    return obj;
}

Instance Method Details

#<<(str) ⇒ Object

call-seq:

<<(str)

Add String str to the current string.

See also Curses::Window.addstr



2351
2352
2353
2354
2355
2356
# File 'ext/curses/curses.c', line 2351

static VALUE
window_addstr2(VALUE obj, VALUE str)
{
    window_addstr(obj, str);
    return obj;
}

#addch(ch) ⇒ Object

Add a character ch, with attributes, to the window, then advance the cursor.

see also the system manual for curs_addch(3)



2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'ext/curses/curses.c', line 2285

static VALUE
window_addch(VALUE obj, VALUE ch)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    waddch(winp->window, NUM2CH(ch));

    return Qnil;
}

#addstr(str) ⇒ Object

add a string of characters str, to the window and advance cursor



2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
# File 'ext/curses/curses.c', line 2321

static VALUE
window_addstr(VALUE obj, VALUE str)
{
    if (!NIL_P(str)) {
  struct windata *winp;

  StringValue(str);
#if defined(HAVE_WADDNWSTR) && defined(_WIN32)
  str = rb_str_export_to_enc(str, get_wide_encoding());
  GetWINDOW(obj, winp);
  waddnwstr(winp->window, (wchar_t *)RSTRING_PTR(str), RSTRING_LEN(str) / sizeof(wchar_t));
#else
  str = rb_str_export_to_enc(str, terminal_encoding);
  GetWINDOW(obj, winp);
  waddstr(winp->window, StringValueCStr(str));
#endif
    }
    return Qnil;
}

#attroff(attrs) ⇒ Object

Turns off the named attributes attrs without affecting any others.

See also Curses::Window.attrset



2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
# File 'ext/curses/curses.c', line 2638

static VALUE
window_attroff(VALUE obj, VALUE attrs)
{
#ifdef HAVE_WATTROFF
    struct windata *winp;

    GetWINDOW(obj,winp);
    return INT2FIX(wattroff(winp->window,NUM2INT(attrs)));
#else
    return Qtrue;
#endif
}

#attron(attrs) ⇒ Object

Turns on the named attributes attrs without turning any other attributes on or off.

See also Curses::Window.attrset



2660
2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
2679
2680
# File 'ext/curses/curses.c', line 2660

static VALUE
window_attron(VALUE obj, VALUE attrs)
{
#ifdef HAVE_WATTRON
    struct windata *winp;
    VALUE val;

    GetWINDOW(obj,winp);
    val = INT2FIX(wattron(winp->window,NUM2INT(attrs)));
    if (rb_block_given_p()) {
  rb_yield(val);
  wattroff(winp->window,NUM2INT(attrs));
  return val;
    }
    else{
  return val;
    }
#else
    return Qtrue;
#endif
}

#attrset(attrs) ⇒ Object

Sets the current attributes of the given window to attrs.

The following video attributes, defined in <curses.h>, can be passed to the routines Curses::Window.attron, Curses::Window.attroff, and Curses::Window.attrset, or OR’d with the characters passed to addch.

A_NORMAL        Normal display (no highlight)
A_STANDOUT      Best highlighting mode of the terminal.
A_UNDERLINE     Underlining
A_REVERSE       Reverse video
A_BLINK         Blinking
A_DIM           Half bright
A_BOLD          Extra bright or bold
A_PROTECT       Protected mode
A_INVIS         Invisible or blank mode
A_ALTCHARSET    Alternate character set
A_CHARTEXT      Bit-mask to extract a character
COLOR_PAIR(n)   Color-pair number n

TODO: provide some examples here.

see also system manual curs_attr(3)



2708
2709
2710
2711
2712
2713
2714
2715
2716
2717
2718
2719
# File 'ext/curses/curses.c', line 2708

static VALUE
window_attrset(VALUE obj, VALUE attrs)
{
#ifdef HAVE_WATTRSET
    struct windata *winp;

    GetWINDOW(obj,winp);
    return INT2FIX(wattrset(winp->window,NUM2INT(attrs)));
#else
    return Qtrue;
#endif
}

#begxObject

A getter for the beginning column (X coord) of the window



2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
# File 'ext/curses/curses.c', line 2166

static VALUE
window_begx(VALUE obj)
{
    struct windata *winp;
    int x, RB_UNUSED_VAR(y);

    GetWINDOW(obj, winp);
#ifdef getbegyx
    getbegyx(winp->window, y, x);
#else
    x = winp->window->_begx;
#endif
    return INT2FIX(x);
}

#begyObject

A getter for the beginning line (Y coord) of the window



2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
# File 'ext/curses/curses.c', line 2146

static VALUE
window_begy(VALUE obj)
{
    struct windata *winp;
    int RB_UNUSED_VAR(x), y;

    GetWINDOW(obj, winp);
#ifdef getbegyx
    getbegyx(winp->window, y, x);
#else
    y = winp->window->_begy;
#endif
    return INT2FIX(y);
}

#bkgd(ch) ⇒ Object

Set the background of the current window and apply character Integer ch to every character.

see also Curses.bkgd



2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
# File 'ext/curses/curses.c', line 2751

static VALUE
window_bkgd(VALUE obj, VALUE ch)
{
#ifdef HAVE_WBKGD
    struct windata *winp;

    GetWINDOW(obj,winp);
    return (wbkgd(winp->window, NUM2CHTYPE(ch)) == OK) ? Qtrue : Qfalse;
#else
    return Qfalse;
#endif
}

#bkgdset(ch) ⇒ Object

Manipulate the background of the current window with character Integer ch

see also Curses.bkgdset



2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
# File 'ext/curses/curses.c', line 2730

static VALUE
window_bkgdset(VALUE obj, VALUE ch)
{
#ifdef HAVE_WBKGDSET
    struct windata *winp;

    GetWINDOW(obj,winp);
    wbkgdset(winp->window, NUM2CHTYPE(ch));
#endif
    return Qnil;
}

#box(vert, hor) ⇒ Object

set the characters to frame the window in. The vertical vert and horizontal hor character.

win = Curses::Window.new(5,5,5,5) win.box(?|, ?-)



2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
# File 'ext/curses/curses.c', line 2192

static VALUE
window_box(int argc, VALUE *argv, VALUE self)
{
    struct windata *winp;
    VALUE vert, hor, corn;

    rb_scan_args(argc, argv, "21", &vert, &hor, &corn);

    GetWINDOW(self, winp);
    box(winp->window, NUM2CH(vert), NUM2CH(hor));

    if (!NIL_P(corn)) {
  int cur_x, cur_y, x, y;
  chtype c;

  c = NUM2CH(corn);
  getyx(winp->window, cur_y, cur_x);
  x = NUM2INT(window_maxx(self)) - 1;
  y = NUM2INT(window_maxy(self)) - 1;
  wmove(winp->window, 0, 0);
  waddch(winp->window, c);
  wmove(winp->window, y, 0);
  waddch(winp->window, c);
  wmove(winp->window, y, x);
  waddch(winp->window, c);
  wmove(winp->window, 0, x);
  waddch(winp->window, c);
  wmove(winp->window, cur_y, cur_x);
    }

    return Qnil;
}

#clearObject

Clear the window.



1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
# File 'ext/curses/curses.c', line 1777

static VALUE
window_clear(VALUE obj)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    wclear(winp->window);

    return Qnil;
}

#closeObject

Deletes the window, and frees the memory



1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
# File 'ext/curses/curses.c', line 1760

static VALUE
window_close(VALUE obj)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    delwin(winp->window);
    winp->window = 0;

    return Qnil;
}

#clrtoeolObject

Clear the window to the end of line, that the cursor is currently on.



1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
# File 'ext/curses/curses.c', line 1813

static VALUE
window_clrtoeol(VALUE obj)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    wclrtoeol(winp->window);

    return Qnil;
}

#color_set(col) ⇒ Object

Sets the current color of the given window to the foreground/background combination described by the Fixnum col.



2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
# File 'ext/curses/curses.c', line 2576

static VALUE
window_color_set(VALUE obj, VALUE col)
{
    struct windata *winp;
    int res;

    GetWINDOW(obj, winp);
    res = wcolor_set(winp->window, NUM2INT(col), NULL);
    return (res == OK) ? Qtrue : Qfalse;
}

#curxObject

A getter for the current column (X coord) of the window



2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
# File 'ext/curses/curses.c', line 2082

static VALUE
window_curx(VALUE obj)
{
    struct windata *winp;
    int x, RB_UNUSED_VAR(y);

    GetWINDOW(obj, winp);
    getyx(winp->window, y, x);
    return INT2FIX(x);
}

#curyObject

A getter for the current line (Y coord) of the window



2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
# File 'ext/curses/curses.c', line 2066

static VALUE
window_cury(VALUE obj)
{
    struct windata *winp;
    int RB_UNUSED_VAR(x), y;

    GetWINDOW(obj, winp);
    getyx(winp->window, y, x);
    return INT2FIX(y);
}

#delchObject

Delete the character under the cursor



2441
2442
2443
2444
2445
2446
2447
2448
2449
# File 'ext/curses/curses.c', line 2441

static VALUE
window_delch(VALUE obj)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    wdelch(winp->window);
    return Qnil;
}

#deletelnObject

Delete the line under the cursor.



2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
# File 'ext/curses/curses.c', line 2457

static VALUE
window_deleteln(VALUE obj)
{
#if defined(HAVE_WDELETELN) || defined(wdeleteln)
    struct windata *winp;

    GetWINDOW(obj, winp);
    wdeleteln(winp->window);
#endif
    return Qnil;
}

#derwin(height, width, relative_top, relative_left) ⇒ Object

Construct a new subwindow with constraints of height lines, width columns, begin at top line, and begin left most column relative to the parent window.



1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
# File 'ext/curses/curses.c', line 1733

static VALUE
window_derwin(VALUE obj, VALUE height, VALUE width, VALUE top, VALUE left)
{
    struct windata *winp;
    WINDOW *window;
    VALUE win;
    int h, w, t, l;

    h = NUM2INT(height);
    w = NUM2INT(width);
    t = NUM2INT(top);
    l = NUM2INT(left);
    GetWINDOW(obj, winp);
    window = derwin(winp->window, h, w, t, l);
    win = prep_window(rb_obj_class(obj), window);

    return win;
}

#eraseObject

Erase the window.



1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
# File 'ext/curses/curses.c', line 1794

static VALUE
window_erase(VALUE obj)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    werase(winp->window);

    return Qnil;
}

#get_charObject

Read and returns a character or function key from the window. A single or multibyte character is represented by a String, and a function key is represented by an Integer. Returns nil if no input is ready.

See Curses::Key to all the function KEY_* available



4587
4588
4589
4590
4591
4592
4593
4594
4595
4596
4597
4598
4599
4600
4601
4602
4603
4604
4605
4606
4607
4608
4609
4610
4611
4612
4613
4614
4615
4616
4617
4618
4619
4620
4621
# File 'ext/curses/curses.c', line 4587

static VALUE
window_get_char(VALUE obj)
{
#ifdef HAVE_WGET_WCH
    struct windata *winp;
    struct wget_wch_arg arg;

    GetWINDOW(obj, winp);
    arg.win = winp->window;
    rb_thread_call_without_gvl(wget_wch_func, &arg, RUBY_UBF_IO, 0);
    switch (arg.retval) {
    case OK:
  return keyboard_uint_chr(arg.ch);
    case KEY_CODE_YES:
  return key_code_value(arg.ch);
    }
    return Qnil;
#else
    struct windata *winp;
    struct wgetch_arg arg;

    GetWINDOW(obj, winp);
    arg.win = winp->window;
    rb_thread_call_without_gvl(wgetch_func, (void *)&arg, RUBY_UBF_IO, 0);
    if (arg.c > 0xff) {
  return INT2NUM(arg.c);
    }
    else if (arg.c >= 0) {
  return keyboard_uint_chr(arg.c);
    }
    else {
  return Qnil;
    }
#endif
}

#getbkgdObject

Returns an Integer (ch) for the character property in the current window.



2769
2770
2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
# File 'ext/curses/curses.c', line 2769

static VALUE
window_getbkgd(VALUE obj)
{
#ifdef HAVE_WGETBKGD
    chtype c;
    struct windata *winp;

    GetWINDOW(obj,winp);
    return (c = getbkgd(winp->window) != ERR) ? ULONG2NUM(c) : Qnil;
#else
    return Qnil;
#endif
}

#getchObject

Read and returns a character from the window.

See Curses::Key to all the function KEY_* available



2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
2394
2395
2396
2397
# File 'ext/curses/curses.c', line 2379

static VALUE
window_getch(VALUE obj)
{
    struct windata *winp;
    struct wgetch_arg arg;
    int c;

    GetWINDOW(obj, winp);
    arg.win = winp->window;
    rb_thread_call_without_gvl(wgetch_func, (void *)&arg, RUBY_UBF_IO, 0);
    c = arg.c;
    if (c == EOF) return Qnil;
    if (rb_isprint(c)) {
  char ch = (char)c;

  return rb_external_str_new_with_enc(&ch, 1, keyboard_encoding);
    }
    return UINT2NUM(c);
}

#getstrObject

This is equivalent to a series f Curses::Window.getch calls



2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
2432
2433
# File 'ext/curses/curses.c', line 2422

static VALUE
window_getstr(VALUE obj)
{
    struct windata *winp;
    struct wgetstr_arg arg;

    GetWINDOW(obj, winp);
    arg.win = winp->window;
    rb_thread_call_without_gvl(wgetstr_func, (void *)&arg, RUBY_UBF_IO, 0);
    return rb_external_str_new_with_enc(arg.rtn, strlen(arg.rtn),
                keyboard_encoding);
}

#idlok(bool) ⇒ Object

If bool is true curses considers using the hardware insert/delete line feature of terminals so equipped.

If bool is false, disables use of line insertion and deletion. This option should be enabled only if the application needs insert/delete line, for example, for a screen editor.

It is disabled by default because insert/delete line tends to be visually annoying when used in applications where it is not really needed. If insert/delete line cannot be used, curses redraws the changed portions of all lines.



2528
2529
2530
2531
2532
2533
2534
2535
2536
# File 'ext/curses/curses.c', line 2528

static VALUE
window_idlok(VALUE obj, VALUE bf)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    idlok(winp->window, RTEST(bf) ? TRUE : FALSE);
    return Qnil;
}

#inchObject

Returns the character at the current position of the window.



2268
2269
2270
2271
2272
2273
2274
2275
# File 'ext/curses/curses.c', line 2268

static VALUE
window_inch(VALUE obj)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    return CH2FIX(winch(winp->window));
}

#insch(ch) ⇒ Object

Insert a character ch, before the cursor, in the current window



2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
# File 'ext/curses/curses.c', line 2303

static VALUE
window_insch(VALUE obj, VALUE ch)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    winsch(winp->window, NUM2CH(ch));

    return Qnil;
}

#insertlnObject

Inserts a line above the cursor, and the bottom line is lost



2475
2476
2477
2478
2479
2480
2481
2482
2483
2484
2485
# File 'ext/curses/curses.c', line 2475

static VALUE
window_insertln(VALUE obj)
{
#if defined(HAVE_WINSERTLN) || defined(winsertln)
    struct windata *winp;

    GetWINDOW(obj, winp);
    winsertln(winp->window);
#endif
    return Qnil;
}

#keypad(bool) ⇒ Object

Enables the keypad of the user’s terminal.

If enabled (bool is true), the user can press a function key (such as an arrow key) and wgetch returns a single value representing the function key, as in KEY_LEFT. If disabled (bool is false), curses does not treat function keys specially and the program has to interpret the escape sequences itself. If the keypad in the terminal can be turned on (made to transmit) and off (made to work locally), turning on this option causes the terminal keypad to be turned on when Curses::Window.getch is called.

The default value for keypad is false.



2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
2847
# File 'ext/curses/curses.c', line 2832

static VALUE
window_keypad(VALUE obj, VALUE val)
{
    struct windata *winp;

    GetWINDOW(obj,winp);
    /* keypad() of NetBSD's libcurses returns no value */
#if defined(__NetBSD__) && !defined(NCURSES_VERSION)
    keypad(winp->window,(RTEST(val) ? TRUE : FALSE));
    return Qnil;
#else
    /* may have to raise exception on ERR */
    return (keypad(winp->window,RTEST(val) ? TRUE : FALSE)) == OK ?
  Qtrue : Qfalse;
#endif
}

#keypad(bool) ⇒ Object

Enables the keypad of the user’s terminal.

If enabled (bool is true), the user can press a function key (such as an arrow key) and wgetch returns a single value representing the function key, as in KEY_LEFT. If disabled (bool is false), curses does not treat function keys specially and the program has to interpret the escape sequences itself. If the keypad in the terminal can be turned on (made to transmit) and off (made to work locally), turning on this option causes the terminal keypad to be turned on when Curses::Window.getch is called.

The default value for keypad is false.



2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
2847
# File 'ext/curses/curses.c', line 2832

static VALUE
window_keypad(VALUE obj, VALUE val)
{
    struct windata *winp;

    GetWINDOW(obj,winp);
    /* keypad() of NetBSD's libcurses returns no value */
#if defined(__NetBSD__) && !defined(NCURSES_VERSION)
    keypad(winp->window,(RTEST(val) ? TRUE : FALSE));
    return Qnil;
#else
    /* may have to raise exception on ERR */
    return (keypad(winp->window,RTEST(val) ? TRUE : FALSE)) == OK ?
  Qtrue : Qfalse;
#endif
}

#line_touched?(line) ⇒ Boolean

Return true if the specified line has been modified since the last call of refresh.

Returns:



1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
# File 'ext/curses/curses.c', line 1985

static VALUE
window_line_touched(VALUE obj, VALUE line)
{
    struct windata *winp;
    int result, n;

    GetWINDOW(obj, winp);
    n = NUM2INT(line);
    result = is_linetouched(winp->window, n);
    if (result == ERR) {
  rb_raise(rb_eArgError, "Invalid line %d", n);
    }
    return result ? Qtrue : Qfalse;
}

#maxxObject

A getter for the maximum columns for the window



2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
# File 'ext/curses/curses.c', line 2122

static VALUE
window_maxx(VALUE obj)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
#if defined(getmaxx)
    return INT2FIX(getmaxx(winp->window));
#elif defined(getmaxyx)
    {
  int x, RB_UNUSED_VAR(y);
  getmaxyx(winp->window, y, x);
  return INT2FIX(x);
    }
#else
    return INT2FIX(winp->window->_maxx+1);
#endif
}

#maxyObject

A getter for the maximum lines for the window



2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
# File 'ext/curses/curses.c', line 2098

static VALUE
window_maxy(VALUE obj)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
#if defined(getmaxy)
    return INT2FIX(getmaxy(winp->window));
#elif defined(getmaxyx)
    {
  int RB_UNUSED_VAR(x), y;
  getmaxyx(winp->window, y, x);
  return INT2FIX(y);
    }
#else
    return INT2FIX(winp->window->_maxy+1);
#endif
}

#move(y, x) ⇒ Object

Moves the window so that the upper left-hand corner is at position (y, x)



2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
# File 'ext/curses/curses.c', line 2009

static VALUE
window_move(VALUE obj, VALUE y, VALUE x)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    mvwin(winp->window, NUM2INT(y), NUM2INT(x));

    return Qnil;
}

#move_relative(x, y) ⇒ Object

Moves the derived or subwindow inside its parent window. The screen-relative parameters of the window are not changed.



2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
# File 'ext/curses/curses.c', line 2028

static VALUE
window_move_relative(VALUE obj, VALUE y, VALUE x)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    mvderwin(winp->window, NUM2INT(y), NUM2INT(x));

    return Qnil;
}

#nodelay=(bool) ⇒ Object

When in no-delay mode Curses::Window#getch is a non-blocking call. If no input is ready #getch returns ERR.

When in delay mode (bool is false which is the default), Curses::Window#getch blocks until a key is pressed.



2865
2866
2867
2868
2869
2870
2871
2872
2873
2874
2875
2876
2877
2878
# File 'ext/curses/curses.c', line 2865

static VALUE
window_nodelay(VALUE obj, VALUE val)
{
    struct windata *winp;
    GetWINDOW(obj,winp);

    /* nodelay() of NetBSD's libcurses returns no value */
#if defined(__NetBSD__) && !defined(NCURSES_VERSION)
    nodelay(winp->window, RTEST(val) ? TRUE : FALSE);
    return Qnil;
#else
    return nodelay(winp->window,RTEST(val) ? TRUE : FALSE) == OK ? Qtrue : Qfalse;
#endif
}

#noutrefreshObject

Refreshes the windows and lines.

Curses::Window.noutrefresh allows multiple updates with more efficiency than Curses::Window.refresh alone.



1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
# File 'ext/curses/curses.c', line 1849

static VALUE
window_noutrefresh(VALUE obj)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
#ifdef HAVE_DOUPDATE
    wnoutrefresh(winp->window);
#else
    wrefresh(winp->window);
#endif

    return Qnil;
}

#redrawObject

Redraws the entire window.



1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'ext/curses/curses.c', line 1870

static VALUE
window_redraw(VALUE obj)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    redrawwin(winp->window);

    return Qnil;
}

#refreshObject

Refreshes the windows and lines.



1830
1831
1832
1833
1834
1835
1836
1837
1838
1839
# File 'ext/curses/curses.c', line 1830

static VALUE
window_refresh(VALUE obj)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    wrefresh(winp->window);

    return Qnil;
}

#resize(lines, cols) ⇒ Object

Resize the current window to Fixnum lines and Fixnum cols



2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
# File 'ext/curses/curses.c', line 2790

static VALUE
window_resize(VALUE obj, VALUE lin, VALUE col)
{
#if defined(HAVE_WRESIZE)
    struct windata *winp;

    GetWINDOW(obj,winp);
    return wresize(winp->window, NUM2INT(lin), NUM2INT(col)) == OK ? Qtrue : Qfalse;
#else
    return Qnil;
#endif
}

#scrl(num) ⇒ Object

Scrolls the current window Fixnum num lines. The current cursor position is not changed.

For positive num, it scrolls up.

For negative num, it scrolls down.



2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
# File 'ext/curses/curses.c', line 2615

static VALUE
window_scrl(VALUE obj, VALUE n)
{
#ifdef HAVE_WSCRL
    struct windata *winp;

    GetWINDOW(obj, winp);
    /* may have to raise exception on ERR */
    return (wscrl(winp->window,NUM2INT(n)) == OK) ? Qtrue : Qfalse;
#else
    return Qfalse;
#endif
}

#scrollObject

Scrolls the current window up one line.



2593
2594
2595
2596
2597
2598
2599
2600
2601
# File 'ext/curses/curses.c', line 2593

static VALUE
window_scroll(VALUE obj)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    /* may have to raise exception on ERR */
    return (scroll(winp->window) == OK) ? Qtrue : Qfalse;
}

#scrollok(bool) ⇒ Object

Controls what happens when the cursor of a window is moved off the edge of the window or scrolling region, either as a result of a newline action on the bottom line, or typing the last character of the last line.

If disabled, (bool is false), the cursor is left on the bottom line.

If enabled, (bool is true), the window is scrolled up one line (Note that to get the physical scrolling effect on the terminal, it is also necessary to call Curses::Window.idlok)



2502
2503
2504
2505
2506
2507
2508
2509
2510
# File 'ext/curses/curses.c', line 2502

static VALUE
window_scrollok(VALUE obj, VALUE bf)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    scrollok(winp->window, RTEST(bf) ? TRUE : FALSE);
    return Qnil;
}

#setpos(y, x) ⇒ Object

A setter for the position of the cursor in the current window, using coordinates x and y



2051
2052
2053
2054
2055
2056
2057
2058
2059
# File 'ext/curses/curses.c', line 2051

static VALUE
window_setpos(VALUE obj, VALUE y, VALUE x)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    wmove(winp->window, NUM2INT(y), NUM2INT(x));
    return Qnil;
}

#setscrreg(top, bottom) ⇒ Object

Set a software scrolling region in a window. top and bottom are lines numbers of the margin.

If this option and Curses::Window.scrollok are enabled, an attempt to move off the bottom margin line causes all lines in the scrolling region to scroll one line in the direction of the first line. Only the text of the window is scrolled.



2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
# File 'ext/curses/curses.c', line 2552

static VALUE
window_setscrreg(VALUE obj, VALUE top, VALUE bottom)
{
#ifdef HAVE_WSETSCRREG
    struct windata *winp;
    int res;

    GetWINDOW(obj, winp);
    res = wsetscrreg(winp->window, NUM2INT(top), NUM2INT(bottom));
    /* may have to raise exception on ERR */
    return (res == OK) ? Qtrue : Qfalse;
#else
    return Qfalse;
#endif
}

#standendObject

Enables the Normal display (no highlight)

This is equivalent to Curses::Window.attron(A_NORMAL)

see also Curses::Window.attrset



2253
2254
2255
2256
2257
2258
2259
2260
2261
# File 'ext/curses/curses.c', line 2253

static VALUE
window_standend(VALUE obj)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    wstandend(winp->window);
    return Qnil;
}

#standoutObject

Enables the best highlighting mode of the terminal.

This is equivalent to Curses::Window.attron(A_STANDOUT)

see also Curses::Window.attrset



2234
2235
2236
2237
2238
2239
2240
2241
2242
# File 'ext/curses/curses.c', line 2234

static VALUE
window_standout(VALUE obj)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    wstandout(winp->window);
    return Qnil;
}

#subwin(height, width, top, left) ⇒ Object

Construct a new subwindow with constraints of height lines, width columns, begin at top line, and begin left most column.



1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
# File 'ext/curses/curses.c', line 1704

static VALUE
window_subwin(VALUE obj, VALUE height, VALUE width, VALUE top, VALUE left)
{
    struct windata *winp;
    WINDOW *window;
    VALUE win;
    int h, w, t, l;

    h = NUM2INT(height);
    w = NUM2INT(width);
    t = NUM2INT(top);
    l = NUM2INT(left);
    GetWINDOW(obj, winp);
    window = subwin(winp->window, h, w, t, l);
    win = prep_window(rb_obj_class(obj), window);

    return win;
}

#timeout=(delay) ⇒ Object

Sets block and non-blocking reads for the window.

  • If delay is negative, blocking read is used (i.e., waits indefinitely for input).

  • If delay is zero, then non-blocking read is used (i.e., read returns ERR if no input is waiting).

  • If delay is positive, then read blocks for delay milliseconds, and returns ERR if there is still no input.



2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'ext/curses/curses.c', line 2894

static VALUE
window_timeout(VALUE obj, VALUE delay)
{
    struct windata *winp;
    GetWINDOW(obj,winp);

    wtimeout(winp->window,NUM2INT(delay));
    return Qnil;
}

#touchObject

Treat the window as if it has been modified since the last call of refresh.



1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
# File 'ext/curses/curses.c', line 1890

static VALUE
window_touch(VALUE obj)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    touchwin(winp->window);

    return Qnil;
}

#touch_line(y, n, changed = true) ⇒ Object

Make n lines from line y look as if they have (changed = true) or have not (changed = false) been modified since the last call of refresh.



1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
# File 'ext/curses/curses.c', line 1951

static VALUE
window_touch_line(int argc, VALUE *argv, VALUE obj)
{
    struct windata *winp;
    VALUE y, n, changed;
    int result;

    rb_scan_args(argc, argv, "12", &y, &n, &changed);
    if (argc < 2) {
  n = INT2NUM(1);
    }
    if (argc < 3) {
  changed = Qtrue;
    }
    GetWINDOW(obj, winp);
    result = wtouchln(winp->window, NUM2INT(y), NUM2INT(n), RTEST(changed));
    if (result == ERR) {
  rb_raise(rb_eRangeError, "Out of window");
    }

    return Qnil;
}

#touched?Boolean

Return true if the window has been modified since the last call of refresh.

Returns:



1931
1932
1933
1934
1935
1936
1937
1938
# File 'ext/curses/curses.c', line 1931

static VALUE
window_touched(VALUE obj)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    return is_wintouched(winp->window) ? Qtrue : Qfalse;
}

#untouchObject

Treat the window as if it has not been modified since the last call of refresh.



1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
# File 'ext/curses/curses.c', line 1911

static VALUE
window_untouch(VALUE obj)
{
    struct windata *winp;

    GetWINDOW(obj, winp);
    untouchwin(winp->window);

    return Qnil;
}