Class: Curses::Window
- Inherits:
-
Data
- Object
- Data
- Curses::Window
- Defined in:
- ext/curses/curses.c,
ext/curses/curses.c
Overview
Description
The means by which to create and manage frames or windows. While there may be more than one window at a time, only one window will receive input.
Usage
require "curses"
Curses.init_screen
my_str = "LOOK! PONIES!"
height, width = 12, my_str.length + 10
top, left = (Curses.lines - height) / 2, (Curses.cols - width) / 2
bwin = Curses::Window.new(height, width, top, left)
bwin.box("\\", "/")
bwin.refresh
win = bwin.subwin(height - 4, width - 4, top + 2, left + 2)
win.setpos(2, 3)
win.addstr(my_str)
# or even
win << "\nOH REALLY?"
win << "\nYES!! " + my_str
win.refresh
win.getch
win.close
Direct Known Subclasses
Instance Method Summary collapse
-
#<<(str) ⇒ Object
call-seq: <<(str).
-
#addch(ch) ⇒ Object
Add a character
ch, with attributes, to the window, then advance the cursor. -
#addstr(str) ⇒ Object
add a string of characters
str, to the window and advance cursor. -
#attroff(attrs) ⇒ Object
Turns off the named attributes
attrswithout affecting any others. -
#attron(attrs) ⇒ Object
Turns on the named attributes
attrswithout turning any other attributes on or off. -
#attrset(attrs) ⇒ Object
Sets the current attributes of the given window to
attrs. -
#begx ⇒ Object
A getter for the beginning column (X coord) of the window.
-
#begy ⇒ Object
A getter for the beginning line (Y coord) of the window.
-
#bkgd(ch) ⇒ Object
Set the background of the current window and apply character Integer
chto every character. -
#bkgdset(ch) ⇒ Object
Manipulate the background of the current window with character Integer
ch. -
#box(vert, hor) ⇒ Object
set the characters to frame the window in.
-
#clear ⇒ Object
Clear the window.
-
#close ⇒ Object
Deletes the window, and frees the memory.
-
#clrtoeol ⇒ Object
Clear the window to the end of line, that the cursor is currently on.
-
#color_set(col) ⇒ Object
Sets the current color of the given window to the foreground/background combination described by the Fixnum
col. -
#curx ⇒ Object
A getter for the current column (X coord) of the window.
-
#cury ⇒ Object
A getter for the current line (Y coord) of the window.
-
#delch ⇒ Object
Delete the character under the cursor.
-
#deleteln ⇒ Object
Delete the line under the cursor.
-
#erase ⇒ Object
Erase the window.
-
#get_char ⇒ Object
Read and returns a character or function key from the window.
-
#getbkgd ⇒ Object
Returns an Integer (
ch) for the character property in the current window. -
#getch ⇒ Object
Read and returns a character from the window.
-
#getstr ⇒ Object
This is equivalent to a series f Curses::Window.getch calls.
-
#idlok(bool) ⇒ Object
If
boolistruecurses considers using the hardware insert/delete line feature of terminals so equipped. -
#inch ⇒ Object
Returns the character at the current position of the window.
-
#new(height, width, top, left) ⇒ Object
constructor
Construct a new Curses::Window with constraints of
heightlines,widthcolumns, begin attopline, and beginleftmost column. -
#insch(ch) ⇒ Object
Insert a character
ch, before the cursor, in the current window. -
#insertln ⇒ Object
Inserts a line above the cursor, and the bottom line is lost.
-
#keypad(bool) ⇒ Object
Enables the keypad of the user’s terminal.
-
#keypad(bool) ⇒ Object
Enables the keypad of the user’s terminal.
-
#maxx ⇒ Object
A getter for the maximum columns for the window.
-
#maxy ⇒ Object
A getter for the maximum lines for the window.
-
#move(y, x) ⇒ Object
Moves the window so that the upper left-hand corner is at position (
y,x). -
#nodelay=(bool) ⇒ Object
When in no-delay mode Curses::Window#getch is a non-blocking call.
-
#noutrefresh ⇒ Object
Refreshes the windows and lines.
-
#redraw ⇒ Object
Dedraws the entire window.
-
#refresh ⇒ Object
Refreshes the windows and lines.
-
#resize(lines, cols) ⇒ Object
Resize the current window to Fixnum
linesand Fixnumcols. -
#scrl(num) ⇒ Object
Scrolls the current window Fixnum
numlines. -
#scroll ⇒ Object
Scrolls the current window up one line.
-
#scrollok(bool) ⇒ Object
Controls what happens when the cursor of a window is moved off the edge of the window or scrolling region, either as a result of a newline action on the bottom line, or typing the last character of the last line.
-
#setpos(y, x) ⇒ Object
A setter for the position of the cursor in the current window, using coordinates
xandy. -
#setscrreg(top, bottom) ⇒ Object
Set a software scrolling region in a window.
-
#standend ⇒ Object
Enables the Normal display (no highlight).
-
#standout ⇒ Object
Enables the best highlighting mode of the terminal.
-
#subwin(height, width, top, left) ⇒ Object
Construct a new subwindow with constraints of
heightlines,widthcolumns, begin attopline, and beginleftmost column. -
#timeout=(delay) ⇒ Object
Sets block and non-blocking reads for the window.
Constructor Details
#new(height, width, top, left) ⇒ Object
Construct a new Curses::Window with constraints of height lines, width columns, begin at top line, and begin left most column.
A new window using full screen is called as Curses::Window.new(0,0,0,0)
1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 |
# File 'ext/curses/curses.c', line 1527 static VALUE window_initialize(VALUE obj, VALUE h, VALUE w, VALUE top, VALUE left) { struct windata *winp; WINDOW *window; curses_init_screen(); TypedData_Get_Struct(obj, struct windata, &windata_type, winp); if (winp->window) delwin(winp->window); window = newwin(NUM2INT(h), NUM2INT(w), NUM2INT(top), NUM2INT(left)); wclear(window); winp->window = window; return obj; } |
Instance Method Details
#<<(str) ⇒ Object
call-seq:
<<(str)
Add String str to the current string.
See also Curses::Window.addstr
2019 2020 2021 2022 2023 2024 |
# File 'ext/curses/curses.c', line 2019 static VALUE window_addstr2(VALUE obj, VALUE str) { window_addstr(obj, str); return obj; } |
#addch(ch) ⇒ Object
Add a character ch, with attributes, to the window, then advance the cursor.
see also the system manual for curs_addch(3)
1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 |
# File 'ext/curses/curses.c', line 1959 static VALUE window_addch(VALUE obj, VALUE ch) { struct windata *winp; GetWINDOW(obj, winp); waddch(winp->window, NUM2CH(ch)); return Qnil; } |
#addstr(str) ⇒ Object
add a string of characters str, to the window and advance cursor
1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 |
# File 'ext/curses/curses.c', line 1995 static VALUE window_addstr(VALUE obj, VALUE str) { if (!NIL_P(str)) { struct windata *winp; StringValue(str); str = rb_str_export_to_enc(str, terminal_encoding); GetWINDOW(obj, winp); waddstr(winp->window, StringValueCStr(str)); } return Qnil; } |
#attroff(attrs) ⇒ Object
Turns off the named attributes attrs without affecting any others.
See also Curses::Window.attrset
2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 |
# File 'ext/curses/curses.c', line 2306 static VALUE window_attroff(VALUE obj, VALUE attrs) { #ifdef HAVE_WATTROFF struct windata *winp; GetWINDOW(obj,winp); return INT2FIX(wattroff(winp->window,NUM2INT(attrs))); #else return Qtrue; #endif } |
#attron(attrs) ⇒ Object
Turns on the named attributes attrs without turning any other attributes on or off.
See also Curses::Window.attrset
2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 2346 2347 2348 |
# File 'ext/curses/curses.c', line 2328 static VALUE window_attron(VALUE obj, VALUE attrs) { #ifdef HAVE_WATTRON struct windata *winp; VALUE val; GetWINDOW(obj,winp); val = INT2FIX(wattron(winp->window,NUM2INT(attrs))); if (rb_block_given_p()) { rb_yield(val); wattroff(winp->window,NUM2INT(attrs)); return val; } else{ return val; } #else return Qtrue; #endif } |
#attrset(attrs) ⇒ Object
Sets the current attributes of the given window to attrs.
The following video attributes, defined in <curses.h>, can be passed to the routines Curses::Window.attron, Curses::Window.attroff, and Curses::Window.attrset, or OR’d with the characters passed to addch.
A_NORMAL Normal display (no highlight)
A_STANDOUT Best highlighting mode of the terminal.
A_UNDERLINE Underlining
A_REVERSE Reverse video
A_BLINK Blinking
A_DIM Half bright
A_BOLD Extra bright or bold
A_PROTECT Protected mode
A_INVIS Invisible or blank mode
A_ALTCHARSET Alternate character set
A_CHARTEXT Bit-mask to extract a character
COLOR_PAIR(n) Color-pair number n
TODO: provide some examples here.
see also system manual curs_attr(3)
2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 |
# File 'ext/curses/curses.c', line 2376 static VALUE window_attrset(VALUE obj, VALUE attrs) { #ifdef HAVE_WATTRSET struct windata *winp; GetWINDOW(obj,winp); return INT2FIX(wattrset(winp->window,NUM2INT(attrs))); #else return Qtrue; #endif } |
#begx ⇒ Object
A getter for the beginning column (X coord) of the window
1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 |
# File 'ext/curses/curses.c', line 1840 static VALUE window_begx(VALUE obj) { struct windata *winp; int x, RB_UNUSED_VAR(y); GetWINDOW(obj, winp); #ifdef getbegyx getbegyx(winp->window, y, x); #else x = winp->window->_begx; #endif return INT2FIX(x); } |
#begy ⇒ Object
A getter for the beginning line (Y coord) of the window
1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 |
# File 'ext/curses/curses.c', line 1820 static VALUE window_begy(VALUE obj) { struct windata *winp; int RB_UNUSED_VAR(x), y; GetWINDOW(obj, winp); #ifdef getbegyx getbegyx(winp->window, y, x); #else y = winp->window->_begy; #endif return INT2FIX(y); } |
#bkgd(ch) ⇒ Object
Set the background of the current window and apply character Integer ch to every character.
see also Curses.bkgd
2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 |
# File 'ext/curses/curses.c', line 2419 static VALUE window_bkgd(VALUE obj, VALUE ch) { #ifdef HAVE_WBKGD struct windata *winp; GetWINDOW(obj,winp); return (wbkgd(winp->window, NUM2ULONG(ch)) == OK) ? Qtrue : Qfalse; #else return Qfalse; #endif } |
#bkgdset(ch) ⇒ Object
Manipulate the background of the current window with character Integer ch
see also Curses.bkgdset
2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 |
# File 'ext/curses/curses.c', line 2398 static VALUE window_bkgdset(VALUE obj, VALUE ch) { #ifdef HAVE_WBKGDSET struct windata *winp; GetWINDOW(obj,winp); wbkgdset(winp->window, NUM2ULONG(ch)); #endif return Qnil; } |
#box(vert, hor) ⇒ Object
set the characters to frame the window in. The vertical vert and horizontal hor character.
win = Curses::Window.new(5,5,5,5) win.box(?|, ?-)
1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 |
# File 'ext/curses/curses.c', line 1866 static VALUE window_box(int argc, VALUE *argv, VALUE self) { struct windata *winp; VALUE vert, hor, corn; rb_scan_args(argc, argv, "21", &vert, &hor, &corn); GetWINDOW(self, winp); box(winp->window, NUM2CH(vert), NUM2CH(hor)); if (!NIL_P(corn)) { int cur_x, cur_y, x, y; chtype c; c = NUM2CH(corn); getyx(winp->window, cur_y, cur_x); x = NUM2INT(window_maxx(self)) - 1; y = NUM2INT(window_maxy(self)) - 1; wmove(winp->window, 0, 0); waddch(winp->window, c); wmove(winp->window, y, 0); waddch(winp->window, c); wmove(winp->window, y, x); waddch(winp->window, c); wmove(winp->window, 0, x); waddch(winp->window, c); wmove(winp->window, cur_y, cur_x); } return Qnil; } |
#clear ⇒ Object
Clear the window.
1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 |
# File 'ext/curses/curses.c', line 1592 static VALUE window_clear(VALUE obj) { struct windata *winp; GetWINDOW(obj, winp); wclear(winp->window); return Qnil; } |
#close ⇒ Object
Deletes the window, and frees the memory
1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 |
# File 'ext/curses/curses.c', line 1575 static VALUE window_close(VALUE obj) { struct windata *winp; GetWINDOW(obj, winp); delwin(winp->window); winp->window = 0; return Qnil; } |
#clrtoeol ⇒ Object
Clear the window to the end of line, that the cursor is currently on.
1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 |
# File 'ext/curses/curses.c', line 1628 static VALUE window_clrtoeol(VALUE obj) { struct windata *winp; GetWINDOW(obj, winp); wclrtoeol(winp->window); return Qnil; } |
#color_set(col) ⇒ Object
Sets the current color of the given window to the foreground/background combination described by the Fixnum col.
2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 |
# File 'ext/curses/curses.c', line 2244 static VALUE window_color_set(VALUE obj, VALUE col) { struct windata *winp; int res; GetWINDOW(obj, winp); res = wcolor_set(winp->window, NUM2INT(col), NULL); return (res == OK) ? Qtrue : Qfalse; } |
#curx ⇒ Object
A getter for the current column (X coord) of the window
1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 |
# File 'ext/curses/curses.c', line 1756 static VALUE window_curx(VALUE obj) { struct windata *winp; int x, RB_UNUSED_VAR(y); GetWINDOW(obj, winp); getyx(winp->window, y, x); return INT2FIX(x); } |
#cury ⇒ Object
A getter for the current line (Y coord) of the window
1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 |
# File 'ext/curses/curses.c', line 1740 static VALUE window_cury(VALUE obj) { struct windata *winp; int RB_UNUSED_VAR(x), y; GetWINDOW(obj, winp); getyx(winp->window, y, x); return INT2FIX(y); } |
#delch ⇒ Object
Delete the character under the cursor
2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'ext/curses/curses.c', line 2109 static VALUE window_delch(VALUE obj) { struct windata *winp; GetWINDOW(obj, winp); wdelch(winp->window); return Qnil; } |
#deleteln ⇒ Object
Delete the line under the cursor.
2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 |
# File 'ext/curses/curses.c', line 2125 static VALUE window_deleteln(VALUE obj) { #if defined(HAVE_WDELETELN) || defined(wdeleteln) struct windata *winp; GetWINDOW(obj, winp); wdeleteln(winp->window); #endif return Qnil; } |
#erase ⇒ Object
Erase the window.
1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 |
# File 'ext/curses/curses.c', line 1609 static VALUE window_erase(VALUE obj) { struct windata *winp; GetWINDOW(obj, winp); werase(winp->window); return Qnil; } |
#get_char ⇒ Object
Read and returns a character or function key from the window. A single or multibyte character is represented by a String, and a function key is represented by an Integer. Returns nil if no input is ready.
See Curses::Key to all the function KEY_* available
2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 |
# File 'ext/curses/curses.c', line 2882 static VALUE window_get_char(VALUE obj) { #ifdef HAVE_WGET_WCH struct windata *winp; struct wget_wch_arg arg; GetWINDOW(obj, winp); arg.win = winp->window; rb_thread_call_without_gvl(wget_wch_func, &arg, RUBY_UBF_IO, 0); switch (arg.retval) { case OK: return keyboard_uint_chr(arg.ch); case KEY_CODE_YES: return UINT2NUM(arg.ch); } return Qnil; #else struct windata *winp; struct wgetch_arg arg; GetWINDOW(obj, winp); arg.win = winp->window; rb_thread_call_without_gvl(wgetch_func, (void *)&arg, RUBY_UBF_IO, 0); if (arg.c > 0xff) { return INT2NUM(arg.c); } else if (arg.c >= 0) { return keyboard_uint_chr(arg.c); } else { return Qnil; } #endif } |
#getbkgd ⇒ Object
Returns an Integer (ch) for the character property in the current window.
2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 |
# File 'ext/curses/curses.c', line 2437 static VALUE window_getbkgd(VALUE obj) { #ifdef HAVE_WGETBKGD chtype c; struct windata *winp; GetWINDOW(obj,winp); return (c = getbkgd(winp->window) != ERR) ? ULONG2NUM(c) : Qnil; #else return Qnil; #endif } |
#getch ⇒ Object
Read and returns a character from the window.
See Curses::Key to all the function KEY_* available
2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 2062 2063 2064 2065 |
# File 'ext/curses/curses.c', line 2047 static VALUE window_getch(VALUE obj) { struct windata *winp; struct wgetch_arg arg; int c; GetWINDOW(obj, winp); arg.win = winp->window; rb_thread_call_without_gvl(wgetch_func, (void *)&arg, RUBY_UBF_IO, 0); c = arg.c; if (c == EOF) return Qnil; if (rb_isprint(c)) { char ch = (char)c; return rb_external_str_new_with_enc(&ch, 1, keyboard_encoding); } return UINT2NUM(c); } |
#getstr ⇒ Object
This is equivalent to a series f Curses::Window.getch calls
2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 |
# File 'ext/curses/curses.c', line 2090 static VALUE window_getstr(VALUE obj) { struct windata *winp; struct wgetstr_arg arg; GetWINDOW(obj, winp); arg.win = winp->window; rb_thread_call_without_gvl(wgetstr_func, (void *)&arg, RUBY_UBF_IO, 0); return rb_external_str_new_with_enc(arg.rtn, strlen(arg.rtn), keyboard_encoding); } |
#idlok(bool) ⇒ Object
If bool is true curses considers using the hardware insert/delete line feature of terminals so equipped.
If bool is false, disables use of line insertion and deletion. This option should be enabled only if the application needs insert/delete line, for example, for a screen editor.
It is disabled by default because insert/delete line tends to be visually annoying when used in applications where it is not really needed. If insert/delete line cannot be used, curses redraws the changed portions of all lines.
2196 2197 2198 2199 2200 2201 2202 2203 2204 |
# File 'ext/curses/curses.c', line 2196 static VALUE window_idlok(VALUE obj, VALUE bf) { struct windata *winp; GetWINDOW(obj, winp); idlok(winp->window, RTEST(bf) ? TRUE : FALSE); return Qnil; } |
#inch ⇒ Object
Returns the character at the current position of the window.
1942 1943 1944 1945 1946 1947 1948 1949 |
# File 'ext/curses/curses.c', line 1942 static VALUE window_inch(VALUE obj) { struct windata *winp; GetWINDOW(obj, winp); return CH2FIX(winch(winp->window)); } |
#insch(ch) ⇒ Object
Insert a character ch, before the cursor, in the current window
1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 |
# File 'ext/curses/curses.c', line 1977 static VALUE window_insch(VALUE obj, VALUE ch) { struct windata *winp; GetWINDOW(obj, winp); winsch(winp->window, NUM2CH(ch)); return Qnil; } |
#insertln ⇒ Object
Inserts a line above the cursor, and the bottom line is lost
2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 |
# File 'ext/curses/curses.c', line 2143 static VALUE window_insertln(VALUE obj) { #if defined(HAVE_WINSERTLN) || defined(winsertln) struct windata *winp; GetWINDOW(obj, winp); winsertln(winp->window); #endif return Qnil; } |
#keypad(bool) ⇒ Object
Enables the keypad of the user’s terminal.
If enabled (bool is true), the user can press a function key (such as an arrow key) and wgetch returns a single value representing the function key, as in KEY_LEFT. If disabled (bool is false), curses does not treat function keys specially and the program has to interpret the escape sequences itself. If the keypad in the terminal can be turned on (made to transmit) and off (made to work locally), turning on this option causes the terminal keypad to be turned on when Curses::Window.getch is called.
The default value for keypad is false.
2500 2501 2502 2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 |
# File 'ext/curses/curses.c', line 2500 static VALUE window_keypad(VALUE obj, VALUE val) { struct windata *winp; GetWINDOW(obj,winp); /* keypad() of NetBSD's libcurses returns no value */ #if defined(__NetBSD__) && !defined(NCURSES_VERSION) keypad(winp->window,(RTEST(val) ? TRUE : FALSE)); return Qnil; #else /* may have to raise exception on ERR */ return (keypad(winp->window,RTEST(val) ? TRUE : FALSE)) == OK ? Qtrue : Qfalse; #endif } |
#keypad(bool) ⇒ Object
Enables the keypad of the user’s terminal.
If enabled (bool is true), the user can press a function key (such as an arrow key) and wgetch returns a single value representing the function key, as in KEY_LEFT. If disabled (bool is false), curses does not treat function keys specially and the program has to interpret the escape sequences itself. If the keypad in the terminal can be turned on (made to transmit) and off (made to work locally), turning on this option causes the terminal keypad to be turned on when Curses::Window.getch is called.
The default value for keypad is false.
2500 2501 2502 2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 |
# File 'ext/curses/curses.c', line 2500 static VALUE window_keypad(VALUE obj, VALUE val) { struct windata *winp; GetWINDOW(obj,winp); /* keypad() of NetBSD's libcurses returns no value */ #if defined(__NetBSD__) && !defined(NCURSES_VERSION) keypad(winp->window,(RTEST(val) ? TRUE : FALSE)); return Qnil; #else /* may have to raise exception on ERR */ return (keypad(winp->window,RTEST(val) ? TRUE : FALSE)) == OK ? Qtrue : Qfalse; #endif } |
#maxx ⇒ Object
A getter for the maximum columns for the window
1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'ext/curses/curses.c', line 1796 static VALUE window_maxx(VALUE obj) { struct windata *winp; GetWINDOW(obj, winp); #if defined(getmaxx) return INT2FIX(getmaxx(winp->window)); #elif defined(getmaxyx) { int x, y; getmaxyx(winp->window, y, x); return INT2FIX(x); } #else return INT2FIX(winp->window->_maxx+1); #endif } |
#maxy ⇒ Object
A getter for the maximum lines for the window
1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 |
# File 'ext/curses/curses.c', line 1772 static VALUE window_maxy(VALUE obj) { struct windata *winp; GetWINDOW(obj, winp); #if defined(getmaxy) return INT2FIX(getmaxy(winp->window)); #elif defined(getmaxyx) { int x, y; getmaxyx(winp->window, y, x); return INT2FIX(y); } #else return INT2FIX(winp->window->_maxy+1); #endif } |
#move(y, x) ⇒ Object
Moves the window so that the upper left-hand corner is at position (y, x)
1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 |
# File 'ext/curses/curses.c', line 1705 static VALUE window_move(VALUE obj, VALUE y, VALUE x) { struct windata *winp; GetWINDOW(obj, winp); mvwin(winp->window, NUM2INT(y), NUM2INT(x)); return Qnil; } |
#nodelay=(bool) ⇒ Object
When in no-delay mode Curses::Window#getch is a non-blocking call. If no input is ready #getch returns ERR.
When in delay mode (bool is false which is the default), Curses::Window#getch blocks until a key is pressed.
2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 |
# File 'ext/curses/curses.c', line 2533 static VALUE window_nodelay(VALUE obj, VALUE val) { struct windata *winp; GetWINDOW(obj,winp); /* nodelay() of NetBSD's libcurses returns no value */ #if defined(__NetBSD__) && !defined(NCURSES_VERSION) nodelay(winp->window, RTEST(val) ? TRUE : FALSE); return Qnil; #else return nodelay(winp->window,RTEST(val) ? TRUE : FALSE) == OK ? Qtrue : Qfalse; #endif } |
#noutrefresh ⇒ Object
Refreshes the windows and lines.
Curses::Window.noutrefresh allows multiple updates with more efficiency than Curses::Window.refresh alone.
1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 |
# File 'ext/curses/curses.c', line 1664 static VALUE window_noutrefresh(VALUE obj) { struct windata *winp; GetWINDOW(obj, winp); #ifdef HAVE_DOUPDATE wnoutrefresh(winp->window); #else wrefresh(winp->window); #endif return Qnil; } |
#redraw ⇒ Object
Dedraws the entire window.
1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 |
# File 'ext/curses/curses.c', line 1685 static VALUE window_redraw(VALUE obj) { struct windata *winp; GetWINDOW(obj, winp); redrawwin(winp->window); return Qnil; } |
#refresh ⇒ Object
Refreshes the windows and lines.
1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 |
# File 'ext/curses/curses.c', line 1645 static VALUE window_refresh(VALUE obj) { struct windata *winp; GetWINDOW(obj, winp); wrefresh(winp->window); return Qnil; } |
#resize(lines, cols) ⇒ Object
Resize the current window to Fixnum lines and Fixnum cols
2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 |
# File 'ext/curses/curses.c', line 2458 static VALUE window_resize(VALUE obj, VALUE lin, VALUE col) { #if defined(HAVE_WRESIZE) struct windata *winp; GetWINDOW(obj,winp); return wresize(winp->window, NUM2INT(lin), NUM2INT(col)) == OK ? Qtrue : Qfalse; #else return Qnil; #endif } |
#scrl(num) ⇒ Object
Scrolls the current window Fixnum num lines. The current cursor position is not changed.
For positive num, it scrolls up.
For negative num, it scrolls down.
2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 |
# File 'ext/curses/curses.c', line 2283 static VALUE window_scrl(VALUE obj, VALUE n) { #ifdef HAVE_WSCRL struct windata *winp; GetWINDOW(obj, winp); /* may have to raise exception on ERR */ return (wscrl(winp->window,NUM2INT(n)) == OK) ? Qtrue : Qfalse; #else return Qfalse; #endif } |
#scroll ⇒ Object
Scrolls the current window up one line.
2261 2262 2263 2264 2265 2266 2267 2268 2269 |
# File 'ext/curses/curses.c', line 2261 static VALUE window_scroll(VALUE obj) { struct windata *winp; GetWINDOW(obj, winp); /* may have to raise exception on ERR */ return (scroll(winp->window) == OK) ? Qtrue : Qfalse; } |
#scrollok(bool) ⇒ Object
Controls what happens when the cursor of a window is moved off the edge of the window or scrolling region, either as a result of a newline action on the bottom line, or typing the last character of the last line.
If disabled, (bool is false), the cursor is left on the bottom line.
If enabled, (bool is true), the window is scrolled up one line (Note that to get the physical scrolling effect on the terminal, it is also necessary to call Curses::Window.idlok)
2170 2171 2172 2173 2174 2175 2176 2177 2178 |
# File 'ext/curses/curses.c', line 2170 static VALUE window_scrollok(VALUE obj, VALUE bf) { struct windata *winp; GetWINDOW(obj, winp); scrollok(winp->window, RTEST(bf) ? TRUE : FALSE); return Qnil; } |
#setpos(y, x) ⇒ Object
A setter for the position of the cursor in the current window, using coordinates x and y
1725 1726 1727 1728 1729 1730 1731 1732 1733 |
# File 'ext/curses/curses.c', line 1725 static VALUE window_setpos(VALUE obj, VALUE y, VALUE x) { struct windata *winp; GetWINDOW(obj, winp); wmove(winp->window, NUM2INT(y), NUM2INT(x)); return Qnil; } |
#setscrreg(top, bottom) ⇒ Object
Set a software scrolling region in a window. top and bottom are lines numbers of the margin.
If this option and Curses::Window.scrollok are enabled, an attempt to move off the bottom margin line causes all lines in the scrolling region to scroll one line in the direction of the first line. Only the text of the window is scrolled.
2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 |
# File 'ext/curses/curses.c', line 2220 static VALUE window_setscrreg(VALUE obj, VALUE top, VALUE bottom) { #ifdef HAVE_WSETSCRREG struct windata *winp; int res; GetWINDOW(obj, winp); res = wsetscrreg(winp->window, NUM2INT(top), NUM2INT(bottom)); /* may have to raise exception on ERR */ return (res == OK) ? Qtrue : Qfalse; #else return Qfalse; #endif } |
#standend ⇒ Object
Enables the Normal display (no highlight)
This is equivalent to Curses::Window.attron(A_NORMAL)
see also Curses::Window.attrset
1927 1928 1929 1930 1931 1932 1933 1934 1935 |
# File 'ext/curses/curses.c', line 1927 static VALUE window_standend(VALUE obj) { struct windata *winp; GetWINDOW(obj, winp); wstandend(winp->window); return Qnil; } |
#standout ⇒ Object
Enables the best highlighting mode of the terminal.
This is equivalent to Curses::Window.attron(A_STANDOUT)
see also Curses::Window.attrset
1908 1909 1910 1911 1912 1913 1914 1915 1916 |
# File 'ext/curses/curses.c', line 1908 static VALUE window_standout(VALUE obj) { struct windata *winp; GetWINDOW(obj, winp); wstandout(winp->window); return Qnil; } |
#subwin(height, width, top, left) ⇒ Object
Construct a new subwindow with constraints of height lines, width columns, begin at top line, and begin left most column.
1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 |
# File 'ext/curses/curses.c', line 1551 static VALUE window_subwin(VALUE obj, VALUE height, VALUE width, VALUE top, VALUE left) { struct windata *winp; WINDOW *window; VALUE win; int h, w, t, l; h = NUM2INT(height); w = NUM2INT(width); t = NUM2INT(top); l = NUM2INT(left); GetWINDOW(obj, winp); window = subwin(winp->window, h, w, t, l); win = prep_window(rb_obj_class(obj), window); return win; } |
#timeout=(delay) ⇒ Object
Sets block and non-blocking reads for the window.
-
If delay is negative, blocking read is used (i.e., waits indefinitely for input).
-
If delay is zero, then non-blocking read is used (i.e., read returns ERR if no input is waiting).
-
If delay is positive, then read blocks for delay milliseconds, and returns ERR if there is still no input.
2562 2563 2564 2565 2566 2567 2568 2569 2570 |
# File 'ext/curses/curses.c', line 2562 static VALUE window_timeout(VALUE obj, VALUE delay) { struct windata *winp; GetWINDOW(obj,winp); wtimeout(winp->window,NUM2INT(delay)); return Qnil; } |